@@ -215,7 +215,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 				if (currItem != nullptr)
 				{
 					editSearchReplace |= currItem->isTextFrame();
-					editSearchReplace |= (currItem->itemText.length() > 0);
+					editSearchReplace |= currItem->itemText.isNotEmpty();
 					editSearchReplace |= (doc->m_Selection->count() == 1);
 				}
 				(*a_scrActions)["editSearchReplace"]->setEnabled(editSearchReplace);
@@ -224,6 +224,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 				(*a_scrActions)["editCopy"]->setEnabled(currItem != nullptr);
 				(*a_scrActions)["editClearContents"]->setEnabled(currItem != nullptr);
 				(*a_scrActions)["editPaste"]->setEnabled(layerUnlocked && ScMimeData::clipboardHasScribusData());
+				(*a_scrActions)["editPastePlainText"]->setEnabled(layerUnlocked && ScMimeData::clipboardHasScribusData());
 				(*a_scrActions)["editTruncateContents"]->setEnabled((currItem != nullptr) && currItem->isTextFrame());
 
 				scmw->propertiesPalette->setGradientEditMode(false);
@@ -286,6 +287,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 					scmw->setTBvals(currItem);
 				}
 				(*a_scrActions)["editPaste"]->setEnabled(false);
+				(*a_scrActions)["editPastePlainText"]->setEnabled(false);
 				if (currItem != nullptr && currItem->isTextFrame())
 				{
 					scmw->charPalette->setEnabled(true, currItem);
@@ -296,6 +298,7 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 				{
 					bool textFrameEditMode = ((currItem != nullptr) && (currItem->isTextFrame()));
 					(*a_scrActions)["editPaste"]->setEnabled( textFrameEditMode || (currItem == nullptr) );
+					(*a_scrActions)["editPastePlainText"]->setEnabled( textFrameEditMode || (currItem == nullptr) );
 				}
 				setTextEditMode(true);
 
@@ -355,7 +358,10 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 					a_actMgr->saveActionShortcutsPreEditMode();
 					// #11938: Paste is not correctly enabled in modeEditTable
 					if (ScMimeData::clipboardHasScribusData())
+					{
 						(*a_scrActions)["editPaste"]->setEnabled(currItem->isTable());
+						(*a_scrActions)["editPastePlainText"]->setEnabled(currItem->isTable());
+					}
 				}
 			}
 			break;
@@ -465,7 +471,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 	(*a_scrActions)["editPasteContentsAbs"]->setEnabled(isImageFrame);
 	(*a_scrActions)["editEditWithImageEditor"]->setEnabled(isImageFrame && currItem->imageIsAvailable && currItem->isRaster);
 	(*a_scrActions)["editEditRenderSource"]->setEnabled(isImageFrame && currItem && (currItem->isLatexFrame() || currItem->isOSGFrame()));
-	(*a_scrActions)["itemAdjustFrameHeightToText"]->setEnabled(SelectedType == PageItem::TextFrame && currItem->itemText.length() > 0);
+	(*a_scrActions)["itemAdjustFrameHeightToText"]->setEnabled(SelectedType == PageItem::TextFrame && currItem->itemText.isNotEmpty());
 	if (!isImageFrame)
 	{
 		(*a_scrActions)["itemImageIsVisible"]->setChecked(false);
@@ -510,6 +516,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(false);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 			(*a_scrActions)["itemLock"]->setEnabled(false);
 			(*a_scrActions)["itemLockSize"]->setEnabled(false);
 			(*a_scrActions)["itemPrintingEnabled"]->setEnabled(false);
@@ -567,6 +574,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemConvertToPolygon"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(!inAnEditMode);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(true);
 			(*a_scrActions)["toolsUnlinkTextFrame"]->setEnabled(false);
 			(*a_scrActions)["toolsUnlinkTextFrameAndCutText"]->setEnabled(false);
 			(*a_scrActions)["toolsLinkTextFrame"]->setEnabled(false);
@@ -618,6 +626,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemConvertToPolygon"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(!inAnEditMode);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(true);
 
 			(*a_scrActions)["toolsRotate"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["toolsCopyProperties"]->setEnabled(!inAnEditMode);
@@ -677,6 +686,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemSendToPattern"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["itemSendToInline"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["toolsRotate"]->setEnabled(!inAnEditMode);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 			if (doc->appMode == modeEditTable)
 			{
 				const PageItem *i2 = currItem->asTable()->activeCell().textFrame();
@@ -724,6 +734,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(true);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(true);
 
 			(*a_scrActions)["toolsRotate"]->setEnabled(!inAnEditMode);
 			(*a_scrActions)["toolsCopyProperties"]->setEnabled(!inAnEditMode);
@@ -770,6 +781,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 				(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 				(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(!inAnEditMode);
 				(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(!inAnEditMode);
+				(*a_scrActions)["itemShapeEdit"]->setEnabled(true);
 			}
 			else if ((SelectedType == PageItem::RegularPolygon) || (SelectedType == PageItem::Arc)) // Regular Polygon + Arc
 			{
@@ -779,6 +791,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 				(*a_scrActions)["itemConvertToPolygon"]->setEnabled(!inAnEditMode);
 				(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(!inAnEditMode);
 				(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(!inAnEditMode);
+				(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 			}
 			else if (SelectedType == PageItem::PolyLine) //Polyline
 			{
@@ -788,6 +801,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 				(*a_scrActions)["itemConvertToPolygon"]->setEnabled(!inAnEditMode);
 				(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 				(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(!inAnEditMode);
+				(*a_scrActions)["itemShapeEdit"]->setEnabled(true);
 			}
 			else if ((SelectedType == PageItem::Line) || (SelectedType == PageItem::Spiral)) // Line
 			{
@@ -800,6 +814,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 					(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 				(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 				(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(!inAnEditMode);
+				(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 			}
 			else if (SelectedType == PageItem::Symbol)
 			{
@@ -809,6 +824,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 				(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 				(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 				(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(false);
+				(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 			}
 			(*a_scrActions)["toolsEditContents"]->setEnabled(false);
 			(*a_scrActions)["toolsEditWithStoryEditor"]->setEnabled(false);
@@ -835,6 +851,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(false);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 		}
 		(*a_scrActions)["editSearchReplace"]->setEnabled(false);
 
@@ -893,7 +910,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 		(*a_scrActions)["itemLock"]->setEnabled(doc->appMode != modeEditClip);
 		(*a_scrActions)["itemLockSize"]->setEnabled(true);
 		(*a_scrActions)["itemPrintingEnabled"]->setEnabled(true);
-		if (currItem->isGroup())
+		if (doc->m_Selection->containsItemType(PageItem::Group))
 		{
 			(*a_scrActions)["itemUngroup"]->setEnabled(doc->appMode != modeEdit);
 			(*a_scrActions)["itemGroupAdjust"]->setEnabled(doc->appMode != modeEdit);
@@ -913,6 +930,7 @@ void AppModeHelper::enableActionsForSelection(ScribusMainWindow* scmw, ScribusDo
 			(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 			(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(false);
+			(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 			(*a_scrActions)["itemSplitPolygons"]->setEnabled(false);
 			(*a_scrActions)["itemAttachTextToPath"]->setEnabled(false);
 			(*a_scrActions)["itemDetachTextFromPath"]->setEnabled(false);
@@ -1047,6 +1065,7 @@ void AppModeHelper::setSpecialEditMode(bool b)
 	(*a_scrActions)["editCut"]->setEnabled(b2);
 	(*a_scrActions)["editCopy"]->setEnabled(b2);
 	(*a_scrActions)["editPaste"]->setEnabled(b2);
+	(*a_scrActions)["editPastePlainText"]->setEnabled(b2);
 	(*a_scrActions)["editCopyContents"]->setEnabled(b2);
 	(*a_scrActions)["editPasteContents"]->setEnabled(b2);
 	(*a_scrActions)["editPasteContentsAbs"]->setEnabled(b2);
@@ -1131,6 +1150,7 @@ void AppModeHelper::setFrameEditMode(bool b)
 	(*a_scrActions)["editCopy"]->setEnabled(b2);
 	(*a_scrActions)["editCut"]->setEnabled(b2);
 	(*a_scrActions)["editPaste"]->setEnabled(b2);
+	(*a_scrActions)["editPastePlainText"]->setEnabled(b2);
 	(*a_scrActions)["itemDelete"]->setEnabled(b2);
 	(*a_scrActions)["itemLock"]->setEnabled(b2);
 	(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(b2);
@@ -1409,6 +1429,7 @@ void AppModeHelper::changeLayer(ScribusDoc *doc, bool clipScrapHaveData)
 {
 	bool setter = !doc->layerLocked( doc->activeLayer() );
 	(*a_scrActions)["editPaste"]->setEnabled(clipScrapHaveData && setter);
+	(*a_scrActions)["editPastePlainText"]->setEnabled(clipScrapHaveData && setter);
 	(*a_scrActions)["editSelectAll"]->setEnabled(setter);
 	(*a_scrActions)["editSelectAllOnLayer"]->setEnabled(setter);
 	(*a_scrActions)["editDeselectAll"]->setEnabled(false);
@@ -1469,6 +1490,7 @@ void AppModeHelper::mainWindowHasNewDoc(const ScribusDoc *doc, bool clipScrapHav
 	(*a_scrActions)["editCut"]->setEnabled(false);
 	(*a_scrActions)["editCopy"]->setEnabled(false);
 	(*a_scrActions)["editPaste"]->setEnabled(layerUnlocked && clipScrapHaveData);
+	(*a_scrActions)["editPastePlainText"]->setEnabled(layerUnlocked && clipScrapHaveData);
 	(*a_scrActions)["editCopyContents"]->setEnabled(false);
 	(*a_scrActions)["editPasteContents"]->setEnabled(false);
 	(*a_scrActions)["editPasteContentsAbs"]->setEnabled(false);
@@ -1492,7 +1514,7 @@ void AppModeHelper::mainWindowHasNewDoc(const ScribusDoc *doc, bool clipScrapHav
 
 	(*a_scrActions)["viewSnapToGrid"]->setChecked(doc->SnapGrid);
 	(*a_scrActions)["viewSnapToGuides"]->setChecked(doc->SnapGuides);
-	(*a_scrActions)["viewSnapToElements"]->setChecked(doc->SnapElement);
+	(*a_scrActions)["viewSnapToItems"]->setChecked(doc->SnapItems);
 	(*a_scrActions)["viewShowRulers"]->setEnabled(true);
 
 	(*a_scrActions)["insertFrame"]->setEnabled(true);
@@ -1525,6 +1547,7 @@ void AppModeHelper::mainWindowHasNewDoc(const ScribusDoc *doc, bool clipScrapHav
 	(*a_scrActions)["toolsPDFAnnot3D"]->setEnabled(true);
 #endif
 	(*a_scrActions)["toolsPreflightVerifier"]->setEnabled(true);
+	(*a_scrActions)["toolsDocumentLog"]->setEnabled(true);
 	bool setter = doc->DocPages.count() > 1;
 	(*a_scrActions)["pageDelete"]->setEnabled(setter);
 	(*a_scrActions)["pageMove"]->setEnabled(setter);
@@ -1616,7 +1639,7 @@ void AppModeHelper::mainWindowSwitchWin(const ScribusDoc *doc)
 
 	(*a_scrActions)["viewSnapToGrid"]->setChecked(doc->SnapGrid);
 	(*a_scrActions)["viewSnapToGuides"]->setChecked(doc->SnapGuides);
-	(*a_scrActions)["viewSnapToElements"]->setChecked(doc->SnapElement);
+	(*a_scrActions)["viewSnapToItems"]->setChecked(doc->SnapItems);
 
 	enableExperimentalActions(doc);
 }
@@ -1643,6 +1666,7 @@ void AppModeHelper::mainWindowCloseLastDoc()
 	(*a_scrActions)["editMasterPages"]->setEnabled(false);
 	(*a_scrActions)["editNotesStyles"]->setEnabled(false);
 	(*a_scrActions)["editPaste"]->setEnabled(false);
+	(*a_scrActions)["editPastePlainText"]->setEnabled(false);
 	(*a_scrActions)["editRedoAction"]->setEnabled(false);
 	(*a_scrActions)["editReplaceColors"]->setEnabled(false);
 	(*a_scrActions)["editSearchReplace"]->setEnabled(false);
@@ -1727,6 +1751,7 @@ void AppModeHelper::mainWindowCloseLastDoc()
 	(*a_scrActions)["toolsPDFRadioButton"]->setEnabled(false);
 	(*a_scrActions)["toolsPDFTextField"]->setEnabled(false);
 	(*a_scrActions)["toolsPreflightVerifier"]->setEnabled(false);
+	(*a_scrActions)["toolsDocumentLog"]->setEnabled(false);
 	(*a_scrActions)["toolsRotate"]->setEnabled(false);
 	(*a_scrActions)["toolsSelect"]->setEnabled(false);
 	(*a_scrActions)["toolsUnlinkTextFrame"]->setEnabled(false);
@@ -1740,7 +1765,7 @@ void AppModeHelper::mainWindowCloseLastDoc()
 	(*a_scrActions)["viewFitInWindow"]->setEnabled(false);
 	(*a_scrActions)["viewFitWidth"]->setEnabled(false);
 	(*a_scrActions)["viewShowRulers"]->setEnabled(false);
-	(*a_scrActions)["viewSnapToElements"]->setChecked(false);
+	(*a_scrActions)["viewSnapToItems"]->setChecked(false);
 	(*a_scrActions)["viewSnapToGrid"]->setChecked(false);
 	(*a_scrActions)["viewSnapToGuides"]->setChecked(false);
 
@@ -1753,6 +1778,7 @@ void AppModeHelper::mainWindowCloseLastDoc()
 	(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 	(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 	(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(false);
+	(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 	(*a_scrActions)["itemLock"]->setEnabled(false);
 	(*a_scrActions)["itemLockSize"]->setEnabled(false);
 
@@ -1829,6 +1855,7 @@ void AppModeHelper::enableTextStyleActions(bool enabled)
 	(*a_scrActions)["typeEffectSubscript"]->setEnabled(enabled);
 	(*a_scrActions)["typeEffectOutline"]->setEnabled(enabled);
 	(*a_scrActions)["typeEffectShadow"]->setEnabled(enabled);
+	(*a_scrActions)["itemStyleSearch"]->setEnabled(enabled);
 }
 
 void AppModeHelper::setStartupActionsEnabled(bool enabled)
@@ -1869,6 +1896,7 @@ void AppModeHelper::setStartupActionsEnabled(bool enabled)
 	(*a_scrActions)["editCut"]->setEnabled(false);
 	(*a_scrActions)["editCopy"]->setEnabled(false);
 	(*a_scrActions)["editPaste"]->setEnabled(false);
+	(*a_scrActions)["editPastePlainText"]->setEnabled(false);
 //	scrMenuMgr->setMenuEnabled("EditPasteRecent", false);
 	(*a_scrActions)["editClearContents"]->setEnabled(false);
 	(*a_scrActions)["editTruncateContents"]->setEnabled(false);
@@ -1892,6 +1920,7 @@ void AppModeHelper::setStartupActionsEnabled(bool enabled)
 	(*a_scrActions)["insertMarkNote"]->setEnabled(false);
 	(*a_scrActions)["insertMarkIndex"]->setEnabled(false);
 	(*a_scrActions)["toolsPreflightVerifier"]->setEnabled(false);
+	(*a_scrActions)["toolsDocumentLog"]->setEnabled(false);
 	(*a_scrActions)["extrasHyphenateText"]->setEnabled(false);
 	(*a_scrActions)["extrasDeHyphenateText"]->setEnabled(false);
 	(*a_scrActions)["viewFitInWindow"]->setEnabled(false);
@@ -1902,7 +1931,7 @@ void AppModeHelper::setStartupActionsEnabled(bool enabled)
 	(*a_scrActions)["viewFit200"]->setEnabled(false);
 	(*a_scrActions)["viewFit400"]->setEnabled(false);
 	(*a_scrActions)["viewSnapToGuides"]->setChecked(false);
-	(*a_scrActions)["viewSnapToElements"]->setChecked(false);
+	(*a_scrActions)["viewSnapToItems"]->setChecked(false);
 	(*a_scrActions)["viewSnapToGrid"]->setChecked(false);
 	(*a_scrActions)["viewShowRulers"]->setEnabled(false);
 //	scrMenuMgr->setMenuEnabled("Insert", false);
@@ -1940,6 +1969,7 @@ void AppModeHelper::setStartupActionsEnabled(bool enabled)
 	(*a_scrActions)["itemConvertToPolygon"]->setEnabled(false);
 	(*a_scrActions)["itemConvertToTextFrame"]->setEnabled(false);
 	(*a_scrActions)["itemConvertToSymbolFrame"]->setEnabled(false);
+	(*a_scrActions)["itemShapeEdit"]->setEnabled(false);
 	(*a_scrActions)["itemAttachTextToPath"]->setEnabled(false);
 	(*a_scrActions)["itemDetachTextFromPath"]->setEnabled(false);
 	(*a_scrActions)["itemCombinePolygons"]->setEnabled(false);
