@@ -13,7 +13,6 @@ for which a new license (GPL+exception) is in place.
 #include <QPointF>
 
 #include "canvas.h"
-#include "fpoint.h"
 #include "pageitem.h"
 #include "pageitem_table.h"
 #include "scribusdoc.h"
@@ -52,7 +51,7 @@ void ColumnResize::mouseReleaseEvent(QMouseEvent* event)
 {
 	event->accept();
 
-	QPointF gridPoint = globalToTableGrid(event->globalPos());
+	QPointF gridPoint = globalToTableGrid(event->globalPosition());
 
 	// Perform the actual resize of the row.
 	PageItem_Table::ResizeStrategy strategy;
@@ -87,7 +86,7 @@ void ColumnResize::mouseMoveEvent(QMouseEvent* event)
 {
 	event->accept();
 
-	QPointF gridPoint = globalToTableGrid(event->globalPos());
+	QPointF gridPoint = globalToTableGrid(event->globalPosition());
 
 	double requestedWidth = gridPoint.x() - m_columnPositions[m_column];
 	double actualWidth = 0.0;
@@ -98,7 +97,7 @@ void ColumnResize::mouseMoveEvent(QMouseEvent* event)
 		actualWidth = resizeColumnResizeFollowing(requestedWidth);
 
 	// Display width tooltip.
-	m_canvas->displayDoubleHUD(event->globalPos(), tr("Width"), actualWidth);
+	m_canvas->displayDoubleHUD(event->globalPosition(), tr("Width"), actualWidth);
 
 	// Update canvas.
 	m_canvas->update();
