@@ -28,14 +28,12 @@
 #include "fpoint.h"
 #include "prefsmanager.h"
 #include "scribus.h"
-#include "scribusXml.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
 #include "ui/pageselector.h"
 #include "ui/scrspinbox.h"
 #include "undomanager.h"
-#include "util.h"
 #include "util_math.h"
 
 
@@ -102,16 +100,16 @@ void FreehandMode::mouseDoubleClickEvent(QMouseEvent *m)
 
 void FreehandMode::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	PageItem *currItem;
 	m->accept();
-	m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
+	m_canvas->displayCorrectedXYHUD(m->globalPosition(), mousePointDoc.x(), mousePointDoc.y());
 	if (commonMouseMove(m))
 		return;
 	if (m_mouseButtonPressed && (m_doc->appMode == modeDrawFreehandLine))
 	{
-		double newXF = mousePointDoc.x(); //m_view->translateToDoc(m->x(), m->y()).x();
-		double newYF = mousePointDoc.y(); //m_view->translateToDoc(m->x(), m->y()).y();
+		double newXF = mousePointDoc.x();
+		double newYF = mousePointDoc.y();
 		if (!m_poly.empty())
 		{
 			if (FPoint(newXF, newYF) != m_poly.point(m_poly.size()-1))
@@ -155,7 +153,8 @@ void FreehandMode::mouseMoveEvent(QMouseEvent *m)
 		if ((m_mouseButtonPressed) && (m->buttons() & Qt::LeftButton))
 		{
 			QPoint startP = m_canvas->canvasToGlobal(QPointF(m_xp, m_yp));
-			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
+			QPoint globalPos = m->globalPosition().toPoint();
+			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(globalPos)).normalized());
 			m_view->setRedrawMarkerShown(true);
 			m_view->HaveSelRect = true;
 			return;
@@ -165,7 +164,7 @@ void FreehandMode::mouseMoveEvent(QMouseEvent *m)
 
 void FreehandMode::mousePressEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	double Rxp = 0;
 	double Ryp = 0;
 	QTransform pm;
@@ -174,10 +173,9 @@ void FreehandMode::mousePressEvent(QMouseEvent *m)
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
-	m_xp = mousePointDoc.x(); //qRound(m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
-	m_yp = mousePointDoc.y(); //qRound(m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
-//	QRect mpo(m->x()-m_doc->guidesPrefs().grabRadius, m->y()-m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius*2, m_doc->guidesPrefs().grabRadius*2);
+	m_view->registerMousePress(m->globalPosition());
+	m_xp = mousePointDoc.x();
+	m_yp = mousePointDoc.y();
 	Rxp = m_doc->ApplyGridF(FPoint(m_xp, m_yp)).x();
 	m_xp = qRound(Rxp);
 	Ryp = m_doc->ApplyGridF(FPoint(m_xp, m_yp)).y();
@@ -196,8 +194,8 @@ void FreehandMode::mousePressEvent(QMouseEvent *m)
 	}
 	m_poly.resize(0);
 	m_view->deselectItems(false);
-	m_xp = mousePointDoc.x(); //qRound(m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
-	m_yp = mousePointDoc.y(); //qRound(m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
+	m_xp = mousePointDoc.x();
+	m_yp = mousePointDoc.y();
 	m_canvas->setRenderModeFillBuffer();
 	undoManager->setUndoEnabled(false);
 }
@@ -264,6 +262,7 @@ void FreehandMode::mouseReleaseEvent(QMouseEvent *m)
 			//FIXME	
 			m_canvas->m_viewMode.operItemResizing = false;
 			m_doc->changed();
+			m_doc->changedPagePreview();
 		}
 		if (!PrefsManager::instance().appPrefs.uiPrefs.stickyTools)
 		{
@@ -308,9 +307,9 @@ void FreehandMode::mouseReleaseEvent(QMouseEvent *m)
 void FreehandMode::selectPage(QMouseEvent *m)
 {
 	m_mouseButtonPressed = true;
-	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-	m_xp = mousePointDoc.x(); //static_cast<int>(m->x()/m_canvas->scale());
-	m_yp = mousePointDoc.y(); //static_cast<int>(m->y()/m_canvas->scale());
+	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+	m_xp = mousePointDoc.x();
+	m_yp = mousePointDoc.y();
 	m_doc->nodeEdit.deselect();
 	m_view->deselectItems(false);
 
