@@ -87,47 +87,44 @@ void CanvasMode_EditPolygon::drawControls(QPainter* p)
 
 void CanvasMode_EditPolygon::drawControlsPolygon(QPainter* psx, PageItem* currItem)
 {
-	QPen p1b = QPen(Qt::blue, 1.0 / m_canvas->m_viewMode.scale, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	QPen p1bd = QPen(Qt::red, 1.0 / m_canvas->m_viewMode.scale, Qt::DotLine, Qt::FlatCap, Qt::MiterJoin);
-	QPen p8b = QPen(Qt::blue, 8.0 / m_canvas->m_viewMode.scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin);
-	QPen p8r = QPen(Qt::red, 8.0 / m_canvas->m_viewMode.scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin);
-	psx->setTransform(currItem->getTransform(), true);
-	psx->setPen(p1b);
-	psx->setBrush(Qt::NoBrush);
+	qreal scale = m_canvas->m_viewMode.scale;
 	PageItem_RegularPolygon* item = currItem->asRegularPolygon();
 	QPainterPath path = regularPolygonPath(item->width(), item->height(), m_polyCorners, m_polyUseFactor, m_polyFactor, m_polyRotation, m_polyCurvature, m_polyInnerRot, m_polyOuterCurvature);
+
+	psx->save();
+	psx->setTransform(currItem->getTransform(), true);
+	psx->setRenderHint(QPainter::Antialiasing);
+
+	// Draw Vector path
+	psx->setPen(pens().value("vector"));
+	psx->setBrush(Qt::NoBrush);
 	psx->drawPath(path);
-	psx->setPen(p1bd);
-	psx->drawLine(m_startPoint, m_endPoint);
+
+	// Draw Control Lines
 	if (m_polyUseFactor)
 	{
+		psx->setPen(pens().value("node-handle"));
 		psx->drawLine(m_endPoint, m_innerCPoint);
 		psx->drawLine(m_startPoint, m_outerCPoint);
 	}
-	psx->setPen(p8b);
-	if (m_polygonPoint == useControlOuter)
-		psx->setPen(p8r);
-	else
-		psx->setPen(p8b);
-	psx->drawPoint(m_startPoint);
-	if (m_polygonPoint == useControlInner)
-		psx->setPen(p8r);
-	else
-		psx->setPen(p8b);
-	psx->drawPoint(m_endPoint);
+	psx->setPen(pens().value("node-dash"));
+	psx->drawLine(m_startPoint, m_endPoint);
+
+	if (currItem->rotation() == 0 || currItem->rotation() == 90 || currItem->rotation() == 180 || currItem->rotation() == 270)
+		psx->setRenderHint(QPainter::Antialiasing, false);
+
+	// Draw Node Handle
+	drawNodeHandle(psx, m_startPoint, pens().value("node"), scale, m_polygonPoint == useControlOuter);
+	drawNodeHandle(psx, m_endPoint, pens().value("node"), scale, m_polygonPoint == useControlInner);
+
+	// Draw Node Controls
 	if (m_polyUseFactor)
 	{
-		if (m_polygonPoint == useControlInnerCurve)
-			psx->setPen(p8r);
-		else
-			psx->setPen(p8b);
-		psx->drawPoint(m_innerCPoint);
-		if (m_polygonPoint == useControlOuterCurve)
-			psx->setPen(p8r);
-		else
-			psx->setPen(p8b);
-		psx->drawPoint(m_outerCPoint);
+		drawNodeControl(psx, m_innerCPoint, pens().value("node"), scale, m_polygonPoint == useControlInnerCurve);
+		drawNodeControl(psx, m_outerCPoint, pens().value("node"), scale, m_polygonPoint == useControlOuterCurve);
 	}
+
+	psx->restore();
 }
 
 void CanvasMode_EditPolygon::enterEvent(QEvent *e)
@@ -162,11 +159,11 @@ void CanvasMode_EditPolygon::updateFromItem()
 	uint cx = m_polyUseFactor ? m_polyCorners * 2 : m_polyCorners;
 	double seg = 360.0 / cx;
 	double trueLength = sqrt(pow(sin(seg / 180.0 * M_PI) * (item->width() / 2.0), 2) + pow(cos(seg / 180.0 * M_PI) * (item->height() / 2.0) + (item->height()/2.0) - item->height(), 2));
-	QLineF innerLine = QLineF(m_endPoint, m_centerPoint);
+	QLineF innerLine(m_endPoint, m_centerPoint);
 	innerLine.setAngle(innerLine.angle() + 90);
 	innerLine.setLength(trueLength * m_polyCurvature);
 	m_innerCPoint = innerLine.p2();
-	QLineF outerLine = QLineF(m_startPoint, currItem->PoLine.pointQF(6));
+	QLineF outerLine(m_startPoint, currItem->PoLine.pointQF(6));
 	outerLine.setLength(outerLine.length() * m_polyOuterCurvature);
 	m_outerCPoint = outerLine.p2();
 	m_view->update();
@@ -202,11 +199,11 @@ void CanvasMode_EditPolygon::activate(bool fromGesture)
 	uint cx = m_polyUseFactor ? m_polyCorners * 2 : m_polyCorners;
 	double seg = 360.0 / cx;
 	double trueLength = sqrt(pow(sin(seg / 180.0 * M_PI) * (item->width() / 2.0), 2) + pow(cos(seg / 180.0 * M_PI) * (item->height() / 2.0) + (item->height()/2.0) - item->height(), 2));
-	QLineF innerLine = QLineF(m_endPoint, m_centerPoint);
+	QLineF innerLine(m_endPoint, m_centerPoint);
 	innerLine.setAngle(innerLine.angle() + 90);
 	innerLine.setLength(trueLength * m_polyCurvature);
 	m_innerCPoint = innerLine.p2();
-	QLineF outerLine = QLineF(m_startPoint, currItem->PoLine.pointQF(6));
+	QLineF outerLine(m_startPoint, currItem->PoLine.pointQF(6));
 	outerLine.setLength(outerLine.length() * m_polyOuterCurvature);
 	m_outerCPoint = outerLine.p2();
 	setModeCursor();
@@ -214,7 +211,7 @@ void CanvasMode_EditPolygon::activate(bool fromGesture)
 		m_view->update();
 	connect(m_doc, SIGNAL(docChanged()), this, SLOT(updateFromItem()));
 	
-	connect(m_VectorDialog, SIGNAL(NewVectors(int, double, bool, double, double, double, double)), this, SLOT(applyValues(int, double, bool, double, double, double, double)));
+	connect(m_VectorDialog, SIGNAL(NewVectors(int,double,bool,double,double,double,double)), this, SLOT(applyValues(int,double,bool,double,double,double,double)));
 	connect(m_VectorDialog, SIGNAL(endEdit()), this, SLOT(endEditing()));
 	connect(m_VectorDialog, SIGNAL(paletteShown(bool)), this, SLOT(endEditing(bool)));
 }
@@ -300,14 +297,14 @@ double CanvasMode_EditPolygon::getUserValFromFactor(double factor)
 	return userVal;
 }
 
-double CanvasMode_EditPolygon::GetZeroFactor()
+double CanvasMode_EditPolygon::GetZeroFactor() const
 {
-	return sqrt(pow(1.0,2.0)-pow(((sin((360.0/(m_polyCorners*2))/180* M_PI)* 2.0)/2.0),2.0));
+	return sqrt(pow(1.0, 2.0) - pow(((sin((360.0 / (m_polyCorners * 2)) / 180 *  M_PI) * 2.0) / 2.0), 2.0));
 }
 
-double CanvasMode_EditPolygon::GetMaxFactor()
+double CanvasMode_EditPolygon::GetMaxFactor() const
 {
-	double win = (360.0/(m_polyCorners*2)) / 180.0 * M_PI;
+	double win = (360.0 / (m_polyCorners * 2)) / 180.0 * M_PI;
 	double ret;
 	if ((360.0/(m_polyCorners*2)) > 45)
 		ret = 1/sin(win);
@@ -336,7 +333,7 @@ void CanvasMode_EditPolygon::mouseDoubleClickEvent(QMouseEvent *m)
 
 void CanvasMode_EditPolygon::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	m->accept();
 	double newX = mousePointDoc.x();
 	double newY = mousePointDoc.y();
@@ -345,7 +342,7 @@ void CanvasMode_EditPolygon::mouseMoveEvent(QMouseEvent *m)
 		PageItem *currItem = m_doc->m_Selection->itemAt(0);
 		QTransform itemMatrix = currItem->getTransform();
 		QPointF cPoint = itemMatrix.map(m_centerPoint);
-		QLineF stLinA = QLineF(cPoint, QPointF(newX, newY));
+		QLineF stLinA(cPoint, QPointF(newX, newY));
 		
 		uint cx = m_polyUseFactor ? m_polyCorners * 2 : m_polyCorners;
 		double seg = 360.0 / cx;
@@ -370,15 +367,15 @@ void CanvasMode_EditPolygon::mouseMoveEvent(QMouseEvent *m)
 		if (m_polygonPoint == useControlInnerCurve)
 		{
 			QPointF ePoint = itemMatrix.map(m_endPoint);
-			QLineF stLinC = QLineF(ePoint, QPointF(newX, newY));
+			QLineF stLinC(ePoint, QPointF(newX, newY));
 			m_polyCurvature = stLinC.length() / trueLength;
 		}
 		if (m_polygonPoint == useControlOuterCurve)
 		{
 			QPointF sPoint = itemMatrix.map(m_startPoint);
 			QPointF sPoint2 = itemMatrix.map(currItem->PoLine.pointQF(6));
-			QLineF stLinCo = QLineF(sPoint, QPointF(newX, newY));
-			QLineF stLinCo2 = QLineF(sPoint, sPoint2);
+			QLineF stLinCo(sPoint, QPointF(newX, newY));
+			QLineF stLinCo2(sPoint, sPoint2);
 			m_polyOuterCurvature = stLinCo.length() / stLinCo2.length();
 		}
 		QPainterPath path = regularPolygonPath(currItem->width(), currItem->height(), m_polyCorners, m_polyUseFactor, m_polyFactor, m_polyRotation, m_polyCurvature, m_polyInnerRot, m_polyOuterCurvature);
@@ -386,11 +383,11 @@ void CanvasMode_EditPolygon::mouseMoveEvent(QMouseEvent *m)
 		ar.fromQPainterPath(path);
 		m_endPoint = ar.pointQF(2);
 		m_startPoint = ar.pointQF(0);
-		QLineF innerLine = QLineF(m_endPoint, m_centerPoint);
+		QLineF innerLine(m_endPoint, m_centerPoint);
 		innerLine.setAngle(innerLine.angle() + 90);
 		innerLine.setLength(trueLength * m_polyCurvature);
 		m_innerCPoint = innerLine.p2();
-		QLineF outerLine = QLineF(m_startPoint, ar.pointQF(6));
+		QLineF outerLine(m_startPoint, ar.pointQF(6));
 		outerLine.setLength(outerLine.length() * m_polyOuterCurvature);
 		m_outerCPoint = outerLine.p2();
 		m_VectorDialog->setValues(m_polyCorners, m_polyFactor, m_polyUseFactor, m_polyRotation, m_polyCurvature, m_polyInnerRot, m_polyOuterCurvature);
@@ -406,7 +403,7 @@ void CanvasMode_EditPolygon::mouseMoveEvent(QMouseEvent *m)
 
 void CanvasMode_EditPolygon::mousePressEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 
 	m_canvas->PaintSizeRect(QRect());
 	m_canvas->m_viewMode.m_MouseButtonPressed = true;
@@ -415,9 +412,9 @@ void CanvasMode_EditPolygon::mousePressEvent(QMouseEvent *m)
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
-	m_Mxp = mousePointDoc.x(); //m->x();
-	m_Myp = mousePointDoc.y(); //m->y();
+	m_view->registerMousePress(m->globalPosition());
+	m_Mxp = mousePointDoc.x();
+	m_Myp = mousePointDoc.y();
 	if (m->button() == Qt::MiddleButton)
 	{
 		m_view->MidButt = true;
@@ -435,10 +432,10 @@ void CanvasMode_EditPolygon::mousePressEvent(QMouseEvent *m)
 	shPoint = itemMatrix.map(shPoint);
 	QPointF sPoint = m_outerCPoint;
 	sPoint = itemMatrix.map(sPoint);
-	bool useOuter = m_canvas->hitsCanvasPoint(m->globalPos(), stPoint);
-	bool useInner = m_canvas->hitsCanvasPoint(m->globalPos(), swPoint);
-	bool useInnerC = m_canvas->hitsCanvasPoint(m->globalPos(), shPoint);
-	bool useOuterC = m_canvas->hitsCanvasPoint(m->globalPos(), sPoint);
+	bool useOuter = m_canvas->hitsCanvasPoint(m->globalPosition(), stPoint);
+	bool useInner = m_canvas->hitsCanvasPoint(m->globalPosition(), swPoint);
+	bool useInnerC = m_canvas->hitsCanvasPoint(m->globalPosition(), shPoint);
+	bool useOuterC = m_canvas->hitsCanvasPoint(m->globalPosition(), sPoint);
 	if (useOuter && useOuterC)
 	{
 		if (m->modifiers() == Qt::ShiftModifier)
@@ -478,7 +475,7 @@ void CanvasMode_EditPolygon::mousePressEvent(QMouseEvent *m)
 
 void CanvasMode_EditPolygon::mouseReleaseEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m->accept();
@@ -490,7 +487,7 @@ void CanvasMode_EditPolygon::mouseReleaseEvent(QMouseEvent *m)
 		double newX = mousePointDoc.x();
 		double newY = mousePointDoc.y();
 		QPointF cPoint = itemMatrix.map(m_centerPoint);
-		QLineF stLinA = QLineF(cPoint, QPointF(newX, newY));
+		QLineF stLinA(cPoint, QPointF(newX, newY));
 		uint cx = m_polyUseFactor ? m_polyCorners * 2 : m_polyCorners;
 		double seg = 360.0 / cx;
 		double trueLength = sqrt(pow(sin(seg / 180.0 * M_PI) * (currItem->width() / 2.0), 2) + pow(cos(seg / 180.0 * M_PI) * (currItem->height() / 2.0) + (currItem->height()/2.0) - currItem->height(), 2));
@@ -504,15 +501,15 @@ void CanvasMode_EditPolygon::mouseReleaseEvent(QMouseEvent *m)
 		if (m_polygonPoint == useControlInnerCurve)
 		{
 			QPointF ePoint = itemMatrix.map(m_endPoint);
-			QLineF stLinC = QLineF(ePoint, QPointF(newX, newY));
+			QLineF stLinC(ePoint, QPointF(newX, newY));
 			m_polyCurvature = stLinC.length() / trueLength;
 		}
 		if (m_polygonPoint == useControlOuterCurve)
 		{
 			QPointF sPoint = itemMatrix.map(m_startPoint);
 			QPointF sPoint2 = itemMatrix.map(currItem->PoLine.pointQF(6));
-			QLineF stLinCo = QLineF(sPoint, QPointF(newX, newY));
-			QLineF stLinCo2 = QLineF(sPoint, sPoint2);
+			QLineF stLinCo(sPoint, QPointF(newX, newY));
+			QLineF stLinCo2(sPoint, sPoint2);
 			m_polyOuterCurvature = stLinCo.length() / stLinCo2.length();
 		}
 		item->polyFactor = m_polyFactor;
