@@ -40,8 +40,8 @@ for which a new license (GPL+exception) is in place.
 
 CanvasMode_EditTable::CanvasMode_EditTable(ScribusView* view) : CanvasMode(view),
 	m_canvasUpdateTimer(new QTimer(view)),
-	m_selectRowCursor(IconManager::instance().loadCursor("select_row.png")),
-	m_selectColumnCursor(IconManager::instance().loadCursor("select_column.png")),
+	m_selectRowCursor(IconManager::instance().loadCursor("cursor-select-row")),
+	m_selectColumnCursor(IconManager::instance().loadCursor("cursor-select-column")),
 	m_tableResizeGesture(new TableResize(this)),
 	m_rowResizeGesture(new RowResize(this)),
 	m_columnResizeGesture(new ColumnResize(this)),
