@@ -6,9 +6,10 @@ for which a new license (GPL+exception) is in place.
 */
 #include "scimgdataloader.h"
 
+#include <QIODevice>
+
 ScImgDataLoader::ScImgDataLoader()
 {
-	initialize();
 }
 
 void ScImgDataLoader::initialize()
@@ -124,9 +125,9 @@ void ScImgDataLoader::parseResourceData( QDataStream & s, const PSDHeader & head
 		s >> signature;
 		offset += 4;
 		if (((signature >> 24)&0xff) != '8' ||
-		        ((signature >> 16)&0xff) != 'B' ||
-		        ((signature >> 8)&0xff) != 'I' ||
-		        ((signature )&0xff) != 'M' )
+				((signature >> 16)&0xff) != 'B' ||
+				((signature >> 8)&0xff) != 'I' ||
+				((signature )&0xff) != 'M' )
 			break;
 		s >> resID;
 		offset += 2;
@@ -226,7 +227,11 @@ void ScImgDataLoader::parseResourceData( QDataStream & s, const PSDHeader & head
 				s >> vResUnit;
 				s >> dummyW;
 				m_imageInfoRecord.xres = qRound(hRes / 65536.0);
+				if (m_imageInfoRecord.xres == 0)
+					m_imageInfoRecord.xres = 72;
 				m_imageInfoRecord.yres = qRound(vRes / 65536.0);
+				if (m_imageInfoRecord.yres == 0)
+					m_imageInfoRecord.yres = 72;
 				break;
 			case 0x040f:
 				m_embeddedProfile.resize(resSize);
@@ -257,11 +262,13 @@ void ScImgDataLoader::parseResourceData( QDataStream & s, const PSDHeader & head
 					m_imageInfoRecord.exifDataValid = true;
 					free(buffer);
 				}
+				break;
 			default:
 				break;
 			}
 		}
-		if (resBase + resSize <= size) {
+		if (resBase + resSize <= size)
+		{
 			s.device()->seek( resBase + resSize );
 			offset += resSize;
 		}
