@@ -31,7 +31,7 @@ for which a new license (GPL+exception) is in place.
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
 #elif defined(DLL_USE_NATIVE_API) && defined(_WIN32)
-#include <windows.h>
+#include <Windows.h>
 #else
 #include <QLibrary>
 #endif
@@ -130,7 +130,7 @@ QString PluginManager::getPluginName(const QString& fileName)
 	QFileInfo fi(fileName);
 	QString baseName(fi.baseName());
 	if (baseName.startsWith("lib"))
-		baseName = baseName.remove(0, 3);
+		baseName.remove(0, 3);
 	if (baseName.endsWith(platformDllExtension()))
 		baseName.chop(1 + platformDllExtension().length());
 	// check name
@@ -224,7 +224,7 @@ void PluginManager::initPlugs()
 	{
 		bool splashShown = ScCore->splashShowing();
 		QString failedStr("<ul>");
-		for (const QString& failedPlug :  failedPlugs)
+		for (const QString& failedPlug : failedPlugs)
 			failedStr += "<li>" + failedPlug + "</li>";
 		failedStr += "</ul>";
 		if (splashShown)
@@ -394,7 +394,7 @@ bool PluginManager::setupPluginActions(StoryEditor *sew)
 		sew->seActions[ai.name]->setEnabled(ai.enabledForStoryEditor);
 
 		// Connect action's activated signal with the plugin's run method
-		it.value().enabled = connect(sew->seActions[ai.name], SIGNAL(triggeredData(QWidget*, ScribusDoc*)), plugin, SLOT(run(QWidget*, ScribusDoc*)));
+		it.value().enabled = connect(sew->seActions[ai.name], SIGNAL(triggeredData(QWidget*,ScribusDoc*)), plugin, SLOT(run(QWidget*,ScribusDoc*)));
 
 		//Get the menu manager to add the DLL's menu item to the right menu, after the chosen existing item
 		if (ai.menuAfterName.isEmpty())
