@@ -4,11 +4,12 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
-#include "commonstrings.h"
+#include <memory>
 
 #include "importai.h"
 #include "importaiplugin.h"
 
+#include "commonstrings.h"
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
@@ -33,14 +34,14 @@ int importai_getPluginAPIVersion()
 
 ScPlugin* importai_getPlugin()
 {
-	ImportAIPlugin* plug = new ImportAIPlugin();
+	auto* plug = new ImportAIPlugin();
 	Q_CHECK_PTR(plug);
 	return plug;
 }
 
 void importai_freePlugin(ScPlugin* plugin)
 {
-	ImportAIPlugin* plug = qobject_cast<ImportAIPlugin*>(plugin);
+	auto* plug = qobject_cast<ImportAIPlugin*>(plugin);
 	Q_ASSERT(plug);
 	delete plug;
 }
@@ -54,6 +55,11 @@ ImportAIPlugin::ImportAIPlugin() :
 	languageChange();
 }
 
+ImportAIPlugin::~ImportAIPlugin()
+{
+	unregisterAll();
+}
+
 void ImportAIPlugin::languageChange()
 {
 	importAction->setText( tr("Import AI..."));
@@ -62,20 +68,14 @@ void ImportAIPlugin::languageChange()
 	fmt->filter = FormatsManager::instance()->extensionsForFormat(FormatsManager::AI); // QFileDialog filter
 }
 
-ImportAIPlugin::~ImportAIPlugin()
-{
-	unregisterAll();
-}
-
 QString ImportAIPlugin::fullTrName() const
 {
 	return QObject::tr("Adobe Illustrator Importer");
 }
 
-
 const ScActionPlugin::AboutData* ImportAIPlugin::getAboutData() const
 {
-	AboutData* about = new AboutData;
+	auto* about = new AboutData;
 	about->authors = "Franz Schmid <franz@scribus.info>";
 	about->shortDescription = tr("Imports Illustrator Files");
 	about->description = tr("Imports most Illustrator files into the current document, converting their vector data into Scribus objects.");
@@ -114,32 +114,33 @@ bool ImportAIPlugin::fileSupported(QIODevice* /* file */, const QString & fileNa
 
 bool ImportAIPlugin::loadFile(const QString & fileName, const FileFormat & /*fmt*/, int flags, int /*index*/)
 {
-	// There's only one format to handle, so we just call import(...)
-	return import(fileName, flags);
+	// There's only one format to handle, so we just call importFile(...)
+	return importFile(fileName, flags);
 }
 
-bool ImportAIPlugin::import(QString fileName, int flags)
+bool ImportAIPlugin::importFile(QString fileName, int flags)
 {
 	if (!checkFlags(flags))
 		return false;
+
 	if (fileName.isEmpty())
 	{
 		flags |= lfInteractive;
 		PrefsContext* prefs = PrefsManager::instance().prefsFile->getPluginContext("importai");
 		QString wdir = prefs->get("wdir", ".");
 		CustomFDialog diaf(ScCore->primaryMainWindow(), wdir, QObject::tr("Open"), FormatsManager::instance()->fileDialogFormatList(FormatsManager::AI));
-		if (diaf.exec())
-		{
-			fileName = diaf.selectedFile();
-			prefs->set("wdir", fileName.left(fileName.lastIndexOf("/")));
-		}
-		else
+		if (!diaf.exec())
 			return true;
+		fileName = diaf.selectedFile();
+		prefs->set("wdir", fileName.left(fileName.lastIndexOf("/")));
 	}
-	m_Doc=ScCore->primaryMainWindow()->doc;
+
+	m_Doc = ScCore->primaryMainWindow()->doc;
+
 	UndoTransaction activeTransaction;
 	bool emptyDoc = (m_Doc == nullptr);
 	bool hasCurrentPage = (m_Doc && m_Doc->currentPage());
+
 	TransactionSettings trSettings;
 	trSettings.targetName   = hasCurrentPage ? m_Doc->currentPage()->getUName() : "";
 	trSettings.targetPixmap = Um::IImageFrame;
@@ -150,10 +151,11 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 		UndoManager::instance()->setUndoEnabled(false);
 	if (UndoManager::undoEnabled())
 		activeTransaction = UndoManager::instance()->beginTransaction(trSettings);
+
 #ifdef HAVE_POPPLER
 	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 	{
-/* Check if the file is an old style AI or one of the newer PDF wrapped ones */
+		/* Check if the file is an old style AI or one of the newer PDF wrapped ones */
 		QFile fT(fileName);
 		if (fT.open(QIODevice::ReadOnly))
 		{
@@ -162,7 +164,7 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 			fT.close();
 			if (tempBuf.startsWith("%PDF"))
 			{
-				qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 				ScMessageBox msgBox(ScCore->primaryMainWindow());
 				msgBox.setText( tr("This file contains 2 versions of the data."));
 				msgBox.setInformativeText( tr("Choose which one should be imported"));
@@ -171,7 +173,7 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 				msgBox.addButton( tr("Use the AI part"), QMessageBox::ActionRole);
 				msgBox.setDefaultButton(pdfButton);
 				msgBox.exec();
-				if ((QPushButton *)msgBox.clickedButton() == pdfButton)
+				if ((QPushButton*) msgBox.clickedButton() == pdfButton)
 				{
 					//Import PDF
 					const FileFormat *fmt = LoadSavePlugin::getFormatByExt("pdf");
@@ -180,7 +182,7 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 						ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, tr("The PDF Import plugin could not be found"));
 						return false;
 					}
-					qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+					QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 					bool success = fmt->loadFile(fileName, flags);
 					if (activeTransaction)
 						activeTransaction.commit();
@@ -190,7 +192,7 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 						ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, tr("The file could not be imported"));
 					return success;
 				}
-				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 			}
 			else if (tempBuf.startsWith("%!PS-Adobe-3.0 EPSF-3.0"))
 			{
@@ -201,7 +203,7 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 					ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, tr("The EPS Import plugin could not be found"));
 					return false;
 				}
-				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 				bool success = fmt->loadFile(fileName, flags);
 				if (activeTransaction)
 					activeTransaction.commit();
@@ -214,16 +216,18 @@ bool ImportAIPlugin::import(QString fileName, int flags)
 		}
 	}
 #endif
-	AIPlug *dia = new AIPlug(m_Doc, flags);
+
+	auto dia = std::make_unique<AIPlug>(m_Doc, flags);
 	Q_CHECK_PTR(dia);
-	bool success = dia->import(fileName, trSettings, flags, !(flags & lfScripted));
+	bool success = dia->importFile(fileName, trSettings, flags, !(flags & lfScripted));
+
 	if (activeTransaction)
 		activeTransaction.commit();
 	if (emptyDoc || !(flags & lfInteractive) || !(flags & lfScripted))
 		UndoManager::instance()->setUndoEnabled(true);
+
 	if (!success)
 		ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, tr("The file could not be imported"));
-	delete dia;
 	return success;
 }
 
@@ -233,11 +237,10 @@ QImage ImportAIPlugin::readThumbnail(const QString& fileName)
 		return QImage();
 	UndoManager::instance()->setUndoEnabled(false);
 	m_Doc = nullptr;
-	AIPlug *dia = new AIPlug(m_Doc, lfCreateThumbnail);
+	auto dia = std::make_unique<AIPlug>(m_Doc, lfCreateThumbnail);
 	Q_CHECK_PTR(dia);
 	QImage ret = dia->readThumbnail(fileName);
 	UndoManager::instance()->setUndoEnabled(true);
-	delete dia;
 	return ret;
 }
 
@@ -247,10 +250,9 @@ bool ImportAIPlugin::readColors(const QString& fileName, ColorList &colors)
 		return false;
 	UndoManager::instance()->setUndoEnabled(false);
 	m_Doc = nullptr;
-	AIPlug *dia = new AIPlug(m_Doc, lfCreateThumbnail);
+	auto dia = std::make_unique<AIPlug>(m_Doc, lfCreateThumbnail);
 	Q_CHECK_PTR(dia);
 	bool ret = dia->readColors(fileName, colors);
 	UndoManager::instance()->setUndoEnabled(true);
-	delete dia;
 	return ret;
 }
