@@ -12,7 +12,6 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMessageBox>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -22,34 +21,19 @@ for which a new license (GPL+exception) is in place.
 #include <libcdr/libcdr.h>
 
 #include "commonstrings.h"
-#include "ui/customfdialog.h"
-#include "fileloader.h"
+#include "documentlogmanager.h"
 #include "loadsaveplugin.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "ui/propertiespalette.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scpattern.h"
 #include "scribus.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusview.h"
-#include "sctextstream.h"
 #include "selection.h"
 #include "undomanager.h"
-#include "util.h"
-#include "util_formats.h"
-#include "util_math.h"
 
 CdrPlug::CdrPlug(ScribusDoc* doc, int flags)
 	   : interactive(flags & LoadSavePlugin::lfInteractive),
@@ -87,7 +71,7 @@ QImage CdrPlug::readThumbnail(const QString& fName)
 		m_Doc->DoDrawing = true;
 		m_Doc->m_Selection->delaySignalsOn();
 		QImage tmpImage;
-		if (Elements.count() > 0)
+		if (!Elements.isEmpty())
 		{
 			for (int dre=0; dre<Elements.count(); ++dre)
 			{
@@ -104,30 +88,31 @@ QImage CdrPlug::readThumbnail(const QString& fName)
 		m_Doc->setLoading(false);
 		m_Doc->m_Selection->delaySignalsOff();
 		delete m_Doc;
+		m_Doc = nullptr;
 		return tmpImage;
 	}
 	QDir::setCurrent(CurDirP);
 	m_Doc->DoDrawing = true;
 	m_Doc->scMW()->setScriptRunning(false);
 	delete m_Doc;
+	m_Doc = nullptr;
 	return QImage();
 }
 
-bool CdrPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool CdrPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-	double b, h;
 	bool ret = false;
 	QFileInfo fi(fNameIn);
-	if ( !ScCore->usingGUI() )
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	if ( showProgress )
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -147,8 +132,8 @@ bool CdrPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
+	double b = 0.0;
+	double h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
@@ -162,7 +147,7 @@ bool CdrPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	docHeight = h;
 	baseX = 0;
 	baseY = 0;
-	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
+	if (m_Doc && (!interactive || (flags & LoadSavePlugin::lfInsertPage)))
 	{
 		m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
 		m_Doc->addPage(0);
@@ -214,7 +199,7 @@ bool CdrPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
 		QGuiApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if ((Elements.count() > 0) && (!ret) && (interactive))
+		if (!Elements.isEmpty() && !ret && interactive)
 		{
 			if (flags & LoadSavePlugin::lfScripted)
 			{
@@ -249,14 +234,14 @@ bool CdrPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 				ScElemMimeData* md = ScriXmlDoc::writeToMimeData(m_Doc, tmpSel);
 				m_Doc->itemSelection_DeleteItem(tmpSel);
 				m_Doc->view()->updatesOn(true);
-				if (importedPatterns.count() != 0)
+				if (!importedPatterns.isEmpty())
 				{
 					for (int cd = 0; cd < importedPatterns.count(); cd++)
 					{
 						m_Doc->docPatterns.remove(importedPatterns[cd]);
 					}
 				}
-				if (importedColors.count() != 0)
+				if (!importedColors.isEmpty())
 				{
 					for (int cd = 0; cd < importedColors.count(); cd++)
 					{
@@ -266,7 +251,7 @@ bool CdrPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 				m_Doc->m_Selection->delaySignalsOff();
 				// We must copy the TransationSettings object as it is owned
 				// by handleObjectImport method afterwards
-				TransactionSettings* transacSettings = new TransactionSettings(trSettings);
+				auto* transacSettings = new TransactionSettings(trSettings);
 				m_Doc->view()->handleObjectImport(md, transacSettings);
 				m_Doc->DragP = false;
 				m_Doc->DraggedElem = nullptr;
@@ -313,8 +298,7 @@ bool CdrPlug::convert(const QString& fn)
 	importedColors.clear();
 	importedPatterns.clear();
 
-	QFile file(fn);
-	if  (!file.exists())
+	if (!QFile::exists(fn))
 	{
 		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist";
 		return false;
@@ -332,6 +316,7 @@ bool CdrPlug::convert(const QString& fn)
 		if (!libcdr::CDRDocument::isSupported(&input))
 		{
 			qDebug() << "ERROR: Unsupported file format!";
+			DocumentLogManager::instance().addLog(m_Doc->uuidString(), DocumentLogLevel::Error, "CoralDraw Importer", DocumentLogManager::msgUnsupportedFileFormat(fn));
 			fail = true;
 		}
 		if (!fail)
@@ -343,6 +328,7 @@ bool CdrPlug::convert(const QString& fn)
 		if (fail)
 		{
 			qDebug() << "ERROR: Parsing failed!";
+			DocumentLogManager::instance().addLog(m_Doc->uuidString(), DocumentLogLevel::Error, "CoralDraw Importer", DocumentLogManager::msgFileImportFailed(fn));
 			if (progressDialog)
 				progressDialog->close();
 		/*	if (importerFlags & LoadSavePlugin::lfCreateDoc)
@@ -360,12 +346,15 @@ bool CdrPlug::convert(const QString& fn)
 		if (!libcdr::CMXDocument::isSupported(&input))
 		{
 			qDebug() << "ERROR: Unsupported file format!";
+			DocumentLogManager::instance().addLog(m_Doc->uuidString(), DocumentLogLevel::Error, "CoralDraw Importer", DocumentLogManager::msgUnsupportedFileFormat(fn));
+
 			return false;
 		}
 		RawPainter painter(m_Doc, baseX, baseY, docWidth, docHeight, importerFlags, &Elements, &importedColors, &importedPatterns, tmpSel, "cmx");
 		if (!libcdr::CMXDocument::parse(&input, &painter))
 		{
 			qDebug() << "ERROR: Parsing failed!";
+			DocumentLogManager::instance().addLog(m_Doc->uuidString(), DocumentLogLevel::Error, "CoralDraw Importer", DocumentLogManager::msgFileImportFailed(fn));
 			if (progressDialog)
 				progressDialog->close();
 			if (importerFlags & LoadSavePlugin::lfCreateDoc)
@@ -380,16 +369,16 @@ bool CdrPlug::convert(const QString& fn)
 	}
 	else
 		return false;
-	if (Elements.count() == 0)
+	if (Elements.isEmpty())
 	{
-		if (importedColors.count() != 0)
+		if (!importedColors.isEmpty())
 		{
 			for (int cd = 0; cd < importedColors.count(); cd++)
 			{
 				m_Doc->PageColors.remove(importedColors[cd]);
 			}
 		}
-		if (importedPatterns.count() != 0)
+		if (!importedPatterns.isEmpty())
 		{
 			for (int cd = 0; cd < importedPatterns.count(); cd++)
 			{
