@@ -34,8 +34,7 @@ class TransactionSettings;
 class ScBitReader
 {
 	public:
-		ScBitReader(QByteArray &data);
-		~ScBitReader();
+		ScBitReader(const QByteArray &data);
 
 		quint32 getUInt(uint size);
 		void alignToWord();
@@ -62,7 +61,7 @@ public:
 	\retval EPSPlug plugin
 	*/
 	CgmPlug( ScribusDoc* doc, int flags );
-	~CgmPlug();
+	~CgmPlug() override;
 
 	/*!
 	\author Franz Schmid
@@ -74,7 +73,7 @@ public:
 	\param showProgress if progress must be displayed
 	\retval bool true if import was ok
 	 */
-	bool import(const QString& fn, const TransactionSettings& trSettings, int flags, bool showProgress = true);
+	bool importFile(const QString& fn, const TransactionSettings& trSettings, int flags, bool showProgress = true);
 	QImage readThumbnail(const QString& fn);
 
 private:
@@ -97,128 +96,130 @@ private:
 	void    getBinaryBezierPath(QDataStream &ts, quint16 paramLen);
 	void    getBinaryPath(QDataStream &ts, quint16 paramLen, bool disjoint = false);
 	void    getBinaryColorTable(QDataStream &ts, quint16 paramLen);
-	ScColor getBinaryDirectColor(ScBitReader *breader);
-	ScColor getBinaryDirectColor(QDataStream &ts);
+	ScColor getBinaryDirectColor(ScBitReader *breader) const;
+	ScColor getBinaryDirectColor(QDataStream &ts) const;
 	QString getBinaryIndexedColor(ScBitReader *breader);
 	QString getBinaryIndexedColor(QDataStream &ts);
 	QString getBinaryColor(QDataStream &ts);
-	double  getBinaryDistance(QDataStream &ts);
-	QPointF getBinaryCoords(QDataStream &ts, bool raw = false);
-	uint    getBinaryUInt(QDataStream &ts, int intP);
-	int     getBinaryInt(QDataStream &ts, int intP);
-	double  getBinaryReal(QDataStream &ts, int realP, int realM);
-	QString getBinaryText(QDataStream &ts);
-	void    alignStreamToWord(QDataStream &ts, uint len);
+	double  getBinaryDistance(QDataStream &ts) const;
+	QPointF getBinaryCoords(QDataStream &ts, bool raw = false) const;
+	uint    getBinaryUInt(QDataStream &ts, int intP) const;
+	int     getBinaryInt(QDataStream &ts, int intP) const;
+	double  getBinaryReal(QDataStream &ts, int realP, int realM) const;
+	QString getBinaryText(QDataStream &ts) const;
+	void    alignStreamToWord(QDataStream &ts, uint len) const;
 
 /* core functions */
 	void    handleStartMetaFile(const QString& value);
 	void    handleStartPicture(const QString& value);
 	void    handleStartPictureBody(double width, double height);
 	void    handleMetaFileDescription(const QString& value);
-	QString handleColor(ScColor &color, const QString& proposedName);
-	double  convertCoords(double input);
-	QPointF convertCoords(QPointF input);
-	void appendPath(QPainterPath &path1, QPainterPath &path2);
+	QString handleColor(const ScColor &color, const QString& proposedName);
+	double  convertCoords(double input) const;
+	QPointF convertCoords(const QPointF& input) const;
+	void appendPath(QPainterPath &path1, const QPainterPath &path2) const;
 	PageItem* itemAdd(PageItem::ItemType itemType, PageItem::ItemFrameType frameType, double x, double y, double b, double h, double w, const QString& fill, const QString& stroke);
 	void    finishItem(PageItem* ite, bool line = true);
 
 /* common variables */
-	int metaFileVersion;
-	int vdcType;
-	int vdcInt;
-	int vdcReal;
-	int vdcMantissa;
-	bool vcdFlippedH;
-	bool vcdFlippedV;
-	double vdcWidth;
-	double vdcHeight;
-	double metaFileScale;
-	double metaScale;
-	int metaFileScaleMode;
-	int intPrecision;
-	int realPrecision;
-	int realMantissa;
-	int realFraction;
-	bool realPrecisionSet;
-	int indexPrecision;
-	int colorPrecision;
-	int colorIndexPrecision;
-	uint maxColorIndex;
-	int m_colorModel;
-	int colorMode;
-	int namePrecision;
-	int lineWidthMode;
-	int edgeWidthMode;
-	int markerSizeMode;
-	double viewPortScale;
-	int viewPortScaleMode;
+	int metaFileVersion { 0 };
+	int vdcType { 0 };
+	int vdcInt { 0 };
+	int vdcReal { 0 };
+	int vdcMantissa { 0 };
+	bool vcdFlippedH { false };
+	bool vcdFlippedV { false };
+	double vdcWidth { 0.0 };
+	double vdcHeight { 0.0 };
+	double metaFileScale { 1.0 };
+	double metaScale { 1.0 };
+	int metaFileScaleMode { 0 };
+	int intPrecision { 0 };
+	int realPrecision { 0 };
+	int realMantissa { 0 };
+	int realFraction { 0 };
+	bool realPrecisionSet { false };
+	int indexPrecision { 0 };
+	int colorPrecision { 0 };
+	int colorIndexPrecision { 0 };
+	uint maxColorIndex { 0 };
+	int m_colorModel { 0 };
+	int colorMode { 0 };
+	int namePrecision { 0 };
+	int lineWidthMode { 0 };
+	int edgeWidthMode { 0 };
+	int markerSizeMode { 0 };
+	double viewPortScale { 1.0 };
+	int viewPortScaleMode { 0 };
 
-	int lineBundleIndex;
-	Qt::PenStyle lineType;
-	Qt::PenCapStyle lineCap;
-	Qt::PenJoinStyle lineJoin;
-	double lineWidth;
-	Qt::PenStyle edgeType;
-	Qt::PenCapStyle edgeCap;
-	Qt::PenJoinStyle edgeJoin;
-	double edgeWidth;
-	uint minColor, maxColor;
+	int lineBundleIndex { 0 };
+	Qt::PenStyle lineType { Qt::NoPen };
+	Qt::PenCapStyle lineCap { Qt::FlatCap };
+	Qt::PenJoinStyle lineJoin { Qt::MiterJoin };
+	double lineWidth { 0.0 };
+	Qt::PenStyle edgeType { Qt::NoPen };
+	Qt::PenCapStyle edgeCap { Qt::FlatCap };
+	Qt::PenJoinStyle edgeJoin { Qt::MiterJoin };
+	double edgeWidth { 0.0 };
+	uint minColor { 0 };
+	uint maxColor { 0 };
 	QString lineColor;
-	bool lineVisible;
+	bool lineVisible { false };
 	QString edgeColor;
 	QString fillColor;
-	int fillType;
-	int patternIndex;
+	int fillType { 0 };
+	int patternIndex { 0 };
 	QMap<int, QString> patternTable;
-	double patternScaleX;
-	double patternScaleY;
+	double patternScaleX { 1.0 };
+	double patternScaleY { 1.0 };
 	QString backgroundColor;
-	bool backgroundSet;
+	bool backgroundSet { false };
 	QMap<uint, QString> ColorTableMap;
 	QRectF clipRect;
-	bool useClipRect;
-	bool clipSet;
+	bool useClipRect { false };
+	bool clipSet { false };
 	QPainterPath regionPath;
-	bool recordRegion;
-	int currentRegion;
+	bool recordRegion { false };
+	int currentRegion { 0 };
 	QMap<int, QPainterPath> regionMap;
 	QPointF fillRefPoint;
 
 	QList<PageItem*> Elements;
-	int currentItemNr;
+	int currentItemNr { 0 };
 	QStack<QList<PageItem*> > groupStack;
 	ColorList CustColors;
-	double baseX, baseY;
-	double docWidth;
-	double docHeight;
+	double baseX { 0.0 };
+	double baseY { 0.0 };
+	double docWidth { 0.0 };
+	double docHeight { 0.0 };
 	QStringList importedColors;
 
 	FPointArray Coords;
-	bool interactive;
-	MultiProgressDialog * progressDialog;
-	bool cancel;
-	ScribusDoc* m_Doc;
-	Selection* tmpSel;
-	int importerFlags;
-	int oldDocItemCount;
+	bool interactive { false };
+	MultiProgressDialog* progressDialog { nullptr };
+	bool cancel { false };
+	ScribusDoc* m_Doc { nullptr };
+	Selection* tmpSel { nullptr };
+	int importerFlags { 0 };
+	int oldDocItemCount { 0 };
 	QString baseFile;
-	bool importRunning;
-	bool firstPage;
-	bool vcdSet;
-	bool wasEndPic;
-	bool recordFigure;
+	bool importRunning { false };
+	bool firstPage { false };
+	bool vcdSet { false };
+	bool wasEndPic { false };
+	bool recordFigure { false };
 	QPainterPath figurePath;
-	bool figClose;
-	int figDocIndex;
-	int figElemIndex;
-	int figGstIndex;
+	bool figClose { false };
+	int figDocIndex { 0 };
+	int figElemIndex { 0 };
+	int figGstIndex { 0 };
 	QString figFillColor;
 	QMap<int, QString> fontID_Map;
-	int m_fontIndex;
+	int m_fontIndex { 0 };
 	QString textColor;
-	int textSize;
-	int textAlignH;
-	int textScaleMode;
+	int textSize { 10 };
+	int textAlignH { 0 };
+	int textScaleMode { 0 };
 	QString pictName;
 
 public slots:
