@@ -11,10 +11,12 @@ for which a new license (GPL+exception) is in place.
     copyright            : (C) 2010 by Franz Schmid
     email                : Franz.Schmid@altmuehlnet.de
  ***************************************************************************/
-#include "commonstrings.h"
+#include <memory>
 
 #include "importdrw.h"
 #include "importdrwplugin.h"
+
+#include "commonstrings.h"
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
@@ -34,7 +36,7 @@ int importdrw_getPluginAPIVersion()
 
 ScPlugin* importdrw_getPlugin()
 {
-	ImportDrwPlugin* plug = new ImportDrwPlugin();
+	auto* plug = new ImportDrwPlugin();
 	Q_CHECK_PTR(plug);
 	return plug;
 }
@@ -77,7 +79,7 @@ QString ImportDrwPlugin::fullTrName() const
 
 const ScActionPlugin::AboutData* ImportDrwPlugin::getAboutData() const
 {
-	AboutData* about = new AboutData;
+	auto* about = new AboutData;
 	about->authors = "Franz Schmid <franz@scribus.info>";
 	about->shortDescription = tr("Imports DRW Files");
 	about->description = tr("Imports most DRW files into the current document, converting their vector data into Scribus objects.");
@@ -114,11 +116,11 @@ bool ImportDrwPlugin::fileSupported(QIODevice* /* file */, const QString & fileN
 
 bool ImportDrwPlugin::loadFile(const QString & fileName, const FileFormat &, int flags, int /*index*/)
 {
-	// There's only one format to handle, so we just call import(...)
-	return import(fileName, flags);
+	// There's only one format to handle, so we just call importFile(...)
+	return importFile(fileName, flags);
 }
 
-bool ImportDrwPlugin::import(QString fileName, int flags)
+bool ImportDrwPlugin::importFile(QString fileName, int flags)
 {
 	if (!checkFlags(flags))
 		return false;
@@ -128,18 +130,18 @@ bool ImportDrwPlugin::import(QString fileName, int flags)
 		PrefsContext* prefs = PrefsManager::instance().prefsFile->getPluginContext("importdrw");
 		QString wdir = prefs->get("wdir", ".");
 		CustomFDialog diaf(ScCore->primaryMainWindow(), wdir, QObject::tr("Open"), tr("All Supported Formats")+" (*.drw *.DRW);;All Files (*)");
-		if (diaf.exec())
-		{
-			fileName = diaf.selectedFile();
-			prefs->set("wdir", fileName.left(fileName.lastIndexOf("/")));
-		}
-		else
+		if (!diaf.exec())
 			return true;
+		fileName = diaf.selectedFile();
+		prefs->set("wdir", fileName.left(fileName.lastIndexOf("/")));
 	}
-	m_Doc=ScCore->primaryMainWindow()->doc;
+
+	m_Doc = ScCore->primaryMainWindow()->doc;
+
 	UndoTransaction activeTransaction;
 	bool emptyDoc = (m_Doc == nullptr);
 	bool hasCurrentPage = (m_Doc && m_Doc->currentPage());
+
 	TransactionSettings trSettings;
 	trSettings.targetName   = hasCurrentPage ? m_Doc->currentPage()->getUName() : "";
 	trSettings.targetPixmap = Um::IImageFrame;
@@ -150,14 +152,16 @@ bool ImportDrwPlugin::import(QString fileName, int flags)
 		UndoManager::instance()->setUndoEnabled(false);
 	if (UndoManager::undoEnabled())
 		activeTransaction = UndoManager::instance()->beginTransaction(trSettings);
-	DrwPlug *dia = new DrwPlug(m_Doc, flags);
+
+	auto dia = std::make_unique<DrwPlug>(m_Doc, flags);
 	Q_CHECK_PTR(dia);
-	dia->import(fileName, trSettings, flags, !(flags & lfScripted));
+	dia->importFile(fileName, trSettings, flags, !(flags & lfScripted));
+
 	if (activeTransaction)
 		activeTransaction.commit();
 	if (emptyDoc || !(flags & lfInteractive) || !(flags & lfScripted))
 		UndoManager::instance()->setUndoEnabled(true);
-	delete dia;
+
 	return true;
 }
 
@@ -167,10 +171,9 @@ QImage ImportDrwPlugin::readThumbnail(const QString& fileName)
 		return QImage();
 	UndoManager::instance()->setUndoEnabled(false);
 	m_Doc = nullptr;
-	DrwPlug *dia = new DrwPlug(m_Doc, lfCreateThumbnail);
+	auto dia = std::make_unique<DrwPlug>(m_Doc, lfCreateThumbnail);
 	Q_CHECK_PTR(dia);
 	QImage ret = dia->readThumbnail(fileName);
 	UndoManager::instance()->setUndoEnabled(true);
-	delete dia;
 	return ret;
 }
