@@ -27,7 +27,8 @@ class PLUGIN_API ImportDrwPlugin : public LoadSavePlugin
 	public:
 		// Standard plugin implementation
 		ImportDrwPlugin();
-		virtual ~ImportDrwPlugin();
+		~ImportDrwPlugin() override;
+
 		/*!
 		\author Franz Schmid
 		\date
@@ -38,7 +39,7 @@ class PLUGIN_API ImportDrwPlugin : public LoadSavePlugin
 		const AboutData* getAboutData() const override;
 		void deleteAboutData(const AboutData* about) const override;
 		void languageChange() override;
-		bool fileSupported(QIODevice* file, const QString & fileName=QString()) const override;
+		bool fileSupported(QIODevice* file, const QString& fileName = QString()) const override;
 		bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0) override;
 		QImage readThumbnail(const QString& fileName) override;
 		void addToMainWindowMenu(ScribusMainWindow *) override {};
@@ -51,11 +52,12 @@ class PLUGIN_API ImportDrwPlugin : public LoadSavePlugin
 		\param fileName input filename, or QString() to prompt.
 		\retval bool always true
 		 */
-		virtual bool import(QString fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
+		bool importFile(QString fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
 
 	private:
 		void registerFormats();
-		ScrAction* importAction;
+
+		ScrAction* importAction { nullptr };
 };
 
 extern "C" PLUGIN_API int importdrw_getPluginAPIVersion();
