@@ -151,7 +151,7 @@ public:
 	\param showProgress if progress must be displayed
 	\retval bool true if import was ok
 	 */
-	bool import(const QString& fn, const TransactionSettings& trSettings, int flags, bool showProgress = true);
+	bool importFile(const QString& fn, const TransactionSettings& trSettings, int flags, bool showProgress = true);
 	QImage readThumbnail(const QString& fn);
 
 private:
@@ -254,20 +254,20 @@ private:
 	PageItem* parsePolyline(QDomElement &e);
 	PageItem* parsePath(QDomElement &e);
 	PageItem* parseFrame(QDomElement &e);
-	void parseText(QDomElement &elem, PageItem* item, ObjStyle& tmpOStyle);
-	void insertChars(PageItem *item, QString &txt, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, int &posC);
-	void applyCharacterStyle(CharStyle &tmpCStyle, ObjStyle &oStyle);
-	void applyParagraphStyle(ParagraphStyle &tmpStyle, ObjStyle &oStyle) const;
+	void parseText(QDomElement &elem, PageItem* item, const ObjStyle& tmpOStyle);
+	void insertChars(PageItem *item, QString &txt, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, int &posC) const;
+	void applyCharacterStyle(CharStyle &tmpCStyle, const ObjStyle & oStyle);
+	void applyParagraphStyle(ParagraphStyle &tmpStyle, const ObjStyle &oStyle) const;
 	void parseTransform(const QString &transform, double *rotation, double *transX, double *transY) const;
 	void parseTransform(FPointArray *composite, const QString &transform) const;
-	void parseViewBox( const QDomElement& object, double *x, double *y, double *w, double *h ) const;
-	void appendPoints(FPointArray *composite, const QDomElement& object, bool closePath);
+	void parseViewBox(const QDomElement& object, double *x, double *y, double *w, double *h) const;
+	void appendPoints(FPointArray *composite, const QDomElement& object, bool closePath) const;
 	void parseStyles(QDomElement &sp);
 	QString getStyleName(QDomElement &e) const;
 	void resovleStyle(ObjStyle &tmpOStyle, const QString& pAttrs);
 	double parseUnit(const QString &unit) const;
 	const char * getCoord(const char *ptr, double &number) const;
-	bool parseEnhPath(const QString& svgPath, FPointArray &result, bool &fill, bool &stroke);
+	bool parseEnhPath(const QString& svgPath, FPointArray &result, bool &fill, bool &stroke) const;
 	double angleFromPoint(const QPointF &point) const;
 	double radSweepAngle(double start, double stop, bool clockwise) const;
 	double degSweepAngle(double start, double stop, bool clockwise) const;
@@ -276,11 +276,11 @@ private:
 	QString modifyColor(const QString& name, bool darker, int amount);
 	QString parseColor( const QString &s );
 	QString constructFontName(const QString& fontBaseName, const QString& fontStyle);
-	QPointF intersectBoundingRect(PageItem *item, QLineF gradientVector) const;
-	PageItem* applyStartArrow(PageItem* item, ObjStyle &obState);
-	PageItem* applyEndArrow(PageItem* ite, ObjStyle &obState);
+	QPointF intersectBoundingRect(const PageItem *item, QLineF gradientVector) const;
+	PageItem* applyStartArrow(const PageItem* item, const ObjStyle &obState);
+	PageItem* applyEndArrow(const PageItem* ite, const ObjStyle &obState);
 	PageItem* groupObjects(QList<PageItem*> &GElements);
-	void finishItem(PageItem* item, ObjStyle &obState);
+	void finishItem(PageItem* item, const ObjStyle &obState);
 
 	QList<PageItem*> Elements;
 	double baseX { 0.0 };
