@@ -80,6 +80,7 @@ QImage PagesPlug::readThumbnail(const QString& fName)
 	if (!uz->open(fName))
 	{
 		delete uz;
+		uz = nullptr;
 		if (progressDialog)
 			progressDialog->close();
 		return QImage();
@@ -180,10 +181,11 @@ QImage PagesPlug::readThumbnail(const QString& fName)
 	}*/
 	uz->close();
 	delete uz;
+	uz = nullptr;
 	return tmp;
 }
 
-bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool PagesPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
@@ -227,7 +229,7 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	baseX = 0;
 	baseY = 0;
-	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
+	if (m_Doc && (!interactive || (flags & LoadSavePlugin::lfInsertPage)))
 	{
 		m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
 		m_Doc->addPage(0);
@@ -235,18 +237,15 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 		baseX = 0;
 		baseY = 0;
 	}
-	else
+	else if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
 	{
-		if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
-		{
-			m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
-			ScCore->primaryMainWindow()->HaveNewDoc();
-			ret = true;
-			baseX = 0;
-			baseY = 0;
-			baseX = m_Doc->currentPage()->xOffset();
-			baseY = m_Doc->currentPage()->yOffset() + m_Doc->currentPage()->height() / 2.0;
-		}
+		m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
+		ScCore->primaryMainWindow()->HaveNewDoc();
+		ret = true;
+		baseX = 0;
+		baseY = 0;
+		baseX = m_Doc->currentPage()->xOffset();
+		baseY = m_Doc->currentPage()->yOffset() + m_Doc->currentPage()->height() / 2.0;
 	}
 	if (!ret && interactive)
 	{
@@ -282,7 +281,7 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
 		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if ((Elements.count() > 0) && !ret && interactive)
+		if (!Elements.isEmpty() && !ret && interactive)
 		{
 			if (flags & LoadSavePlugin::lfScripted)
 			{
@@ -317,14 +316,14 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 				ScElemMimeData* md = ScriXmlDoc::writeToMimeData(m_Doc, tmpSel);
 				m_Doc->itemSelection_DeleteItem(tmpSel);
 				m_Doc->view()->updatesOn(true);
-				if ((importedColors.count() != 0) && (!((flags & LoadSavePlugin::lfKeepGradients) || (flags & LoadSavePlugin::lfKeepColors) || (flags & LoadSavePlugin::lfKeepPatterns))))
+				if (!importedColors.isEmpty() && (!((flags & LoadSavePlugin::lfKeepGradients) || (flags & LoadSavePlugin::lfKeepColors) || (flags & LoadSavePlugin::lfKeepPatterns))))
 				{
 					for (int cd = 0; cd < importedColors.count(); cd++)
 					{
 						m_Doc->PageColors.remove(importedColors[cd]);
 					}
 				}
-				if ((importedPatterns.count() != 0) && (!(flags & LoadSavePlugin::lfKeepPatterns)))
+				if (!importedPatterns.isEmpty() && (!(flags & LoadSavePlugin::lfKeepPatterns)))
 				{
 					for (int cd = 0; cd < importedPatterns.count(); cd++)
 					{
@@ -334,7 +333,7 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 				m_Doc->m_Selection->delaySignalsOff();
 				// We must copy the TransationSettings object as it is owned
 				// by handleObjectImport method afterwards
-				TransactionSettings* transacSettings = new TransactionSettings(trSettings);
+				auto* transacSettings = new TransactionSettings(trSettings);
 				m_Doc->view()->handleObjectImport(md, transacSettings);
 				m_Doc->DragP = false;
 				m_Doc->DraggedElem = nullptr;
@@ -395,6 +394,7 @@ bool PagesPlug::convert(const QString& fn)
 	if (!uz->open(fn))
 	{
 		delete uz;
+		uz = nullptr;
 		if (progressDialog)
 			progressDialog->close();
 		return false;
@@ -406,6 +406,7 @@ bool PagesPlug::convert(const QString& fn)
 		retVal = parseDocReference("index.xml.gz", true);
 	uz->close();
 	delete uz;
+	uz = nullptr;
 	if (progressDialog)
 		progressDialog->close();
 	return retVal;
@@ -421,7 +422,8 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 	if (compressed)
 	{
 		QTemporaryFile tmpFile(QDir::tempPath() + "/scribus_temp_zip_XXXXXX.dat");
-		tmpFile.open();
+		if (!tmpFile.open())
+			return false;
 		QString fname = getLongPathName(tmpFile.fileName());
 		tmpFile.write(f);
 		tmpFile.close();
@@ -653,7 +655,7 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 							int count = spg.text().length();
 							QString tgText = spg.text();
 							tgText = tgText.left(count - totalCount);
-							if (tgText.length() > 0)
+							if (!tgText.isEmpty())
 							{
 								itemText.insertChars(posC, tgText);
 								itemText.applyStyle(posC, tmpStyle);
@@ -1165,7 +1167,7 @@ PageItem* PagesPlug::parseObjReference(QDomElement &draw)
 					GElements.append(ite);
 			}
 		}
-		if (GElements.count() > 0)
+		if (!GElements.isEmpty())
 		{
 			QTransform m;
 			m.translate(obState.width / 2.0, obState.height / 2.0);
@@ -1348,7 +1350,7 @@ PageItem* PagesPlug::parseObjReference(QDomElement &draw)
 										int count = spg.text().length();
 										QString tgText = spg.text();
 										tgText = tgText.left(count - totalCount);
-										if (tgText.length() > 0)
+										if (!tgText.isEmpty())
 										{
 											itemText.insertChars(posC, tgText);
 											itemText.applyStyle(posC, tmpStyle);
@@ -1629,7 +1631,7 @@ void PagesPlug::applyCharAttrs(CharStyle &tmpCStyle, const QString& pAttrs)
 	}
 }
 
-void PagesPlug::finishItem(PageItem* item, ObjState &obState)
+void PagesPlug::finishItem(PageItem* item, const ObjState &obState)
 {
 	item->ClipEdited = true;
 	item->FrameType = 3;
