@@ -33,7 +33,8 @@ class PLUGIN_API ImportPagesPlugin : public LoadSavePlugin
 	public:
 		// Standard plugin implementation
 		ImportPagesPlugin();
-		virtual ~ImportPagesPlugin();
+		~ImportPagesPlugin() override;
+
 		/*!
 		\author Franz Schmid
 		\date
@@ -44,7 +45,7 @@ class PLUGIN_API ImportPagesPlugin : public LoadSavePlugin
 		const AboutData* getAboutData() const override;
 		void deleteAboutData(const AboutData* about) const override;
 		void languageChange() override;
-		bool fileSupported(QIODevice* file, const QString & fileName=QString()) const override;
+		bool fileSupported(QIODevice* file, const QString& fileName = QString()) const override;
 		bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0) override;
 		QImage readThumbnail(const QString& fileName) override;
 		void addToMainWindowMenu(ScribusMainWindow *) override {};
@@ -57,11 +58,12 @@ class PLUGIN_API ImportPagesPlugin : public LoadSavePlugin
 		\param fileName input filename, or QString() to prompt.
 		\retval bool always true
 		 */
-		virtual bool import(QString fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
+		bool importFile(QString fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
 
 	private:
 		void registerFormats();
-		ScrAction* importAction;
+
+		ScrAction* importAction { nullptr };
 };
 
 extern "C" PLUGIN_API int importpages_getPluginAPIVersion();
