@@ -83,9 +83,9 @@ QImage PctPlug::readThumbnail(const QString& fName)
 		m_Doc->DoDrawing = true;
 		m_Doc->m_Selection->delaySignalsOn();
 		QImage tmpImage;
-		if (Elements.count() > 0)
+		if (!Elements.isEmpty())
 		{
-			for (int dre=0; dre<Elements.count(); ++dre)
+			for (int dre = 0; dre < Elements.count(); ++dre)
 			{
 				tmpSel->addItem(Elements.at(dre), true);
 			}
@@ -109,7 +109,7 @@ QImage PctPlug::readThumbnail(const QString& fName)
 	return QImage();
 }
 
-bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool PctPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
@@ -139,7 +139,7 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		progressDialog->setProgress("GI", 0);
 		progressDialog->show();
 		connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelRequested()));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	else
 		progressDialog = nullptr;
@@ -151,7 +151,7 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	parseHeader(fNameIn, x, y, b, h);
 	if (b == 0.0)
@@ -162,7 +162,7 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	docHeight = h;
 	baseX = 0;
 	baseY = 0;
-	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
+	if (m_Doc && (!interactive || (flags & LoadSavePlugin::lfInsertPage)))
 	{
 		m_Doc->setPage(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false);
 		m_Doc->addPage(0);
@@ -177,33 +177,30 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		baseX = m_Doc->currentPage()->xOffset();
 		baseY = m_Doc->currentPage()->yOffset();
 	}
-	else
+	else if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
 	{
-		if (!m_Doc || (flags & LoadSavePlugin::lfCreateDoc))
-		{
-			m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
-			ScCore->primaryMainWindow()->HaveNewDoc();
-			m_Doc->setPageHeight(docHeight);
-			m_Doc->setPageWidth(docWidth);
-			m_Doc->currentPage()->setInitialWidth(docWidth);
-			m_Doc->currentPage()->setInitialHeight(docHeight);
-			m_Doc->currentPage()->setWidth(docWidth);
-			m_Doc->currentPage()->setHeight(docHeight);
-			ret = true;
-			baseX = m_Doc->currentPage()->xOffset();
-			baseY = m_Doc->currentPage()->yOffset();
-		}
+		m_Doc = ScCore->primaryMainWindow()->doFileNew(docWidth, docHeight, 0, 0, 0, 0, 0, 0, false, false, 0, false, 0, 1, "Custom", true);
+		ScCore->primaryMainWindow()->HaveNewDoc();
+		m_Doc->setPageHeight(docHeight);
+		m_Doc->setPageWidth(docWidth);
+		m_Doc->currentPage()->setInitialWidth(docWidth);
+		m_Doc->currentPage()->setInitialHeight(docHeight);
+		m_Doc->currentPage()->setWidth(docWidth);
+		m_Doc->currentPage()->setHeight(docHeight);
+		ret = true;
+		baseX = m_Doc->currentPage()->xOffset();
+		baseY = m_Doc->currentPage()->yOffset();
 	}
 	offsetX += m_Doc->currentPage()->xOffset();
 	offsetY += m_Doc->currentPage()->yOffset();
 	offsetX *= -1;
 	offsetY *= -1;
-	if ((!ret) && (interactive))
+	if (!ret && interactive)
 	{
 		baseX = m_Doc->currentPage()->xOffset();
 		baseY = m_Doc->currentPage()->yOffset();
 	}
-	if ((ret) || (!interactive))
+	if (ret || !interactive)
 	{
 		if (docWidth > docHeight)
 			m_Doc->setPageOrientation(1);
@@ -219,7 +216,7 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
 		m_Doc->view()->updatesOn(false);
 	m_Doc->scMW()->setScriptRunning(true);
-	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
 	if (convert(fNameIn))
@@ -231,8 +228,8 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if ((Elements.count() > 0) && (!ret) && (interactive))
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		if (!Elements.isEmpty() && !ret && interactive)
 		{
 			if (flags & LoadSavePlugin::lfScripted)
 			{
@@ -267,14 +264,14 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 				ScElemMimeData* md = ScriXmlDoc::writeToMimeData(m_Doc, tmpSel);
 				m_Doc->itemSelection_DeleteItem(tmpSel);
 				m_Doc->view()->updatesOn(true);
-				if (importedColors.count() != 0)
+				if (!importedColors.isEmpty())
 				{
 					for (int cd = 0; cd < importedColors.count(); cd++)
 					{
 						m_Doc->PageColors.remove(importedColors[cd]);
 					}
 				}
-				if (importedPatterns.count() != 0)
+				if (!importedPatterns.isEmpty())
 				{
 					for (int cd = 0; cd < importedPatterns.count(); cd++)
 					{
@@ -306,17 +303,17 @@ bool PctPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->view()->updatesOn(true);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 	}
 	if (interactive)
 		m_Doc->setLoading(false);
 	//CB If we have a gui we must refresh it if we have used the progressbar
 	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 	{
-		if ((showProgress) && (!interactive))
+		if (showProgress && !interactive)
 			m_Doc->view()->DrawNew();
 	}
-	qApp->restoreOverrideCursor();
+	QApplication::restoreOverrideCursor();
 	return success;
 }
 
@@ -434,7 +431,7 @@ bool PctPlug::convert(const QString& fn)
 	{
 		progressDialog->setOverallProgress(2);
 		progressDialog->setLabel("GI", tr("Generating Items"));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	QFile f(fn);
 	if (f.open(QIODevice::ReadOnly))
@@ -443,7 +440,7 @@ bool PctPlug::convert(const QString& fn)
 		if (progressDialog)
 		{
 			progressDialog->setTotalSteps("GI", fSize);
-			qApp->processEvents();
+			QApplication::processEvents();
 		}
 		QDataStream ts(&f);
 		ts.setByteOrder(QDataStream::BigEndian);
@@ -484,22 +481,12 @@ bool PctPlug::convert(const QString& fn)
 			ts.skipRawData(22);
 			parsePict(ts);
 		}
-		if (Elements.count() == 0)
+		if (Elements.isEmpty())
 		{
-			if (importedColors.count() != 0)
-			{
-				for (int cd = 0; cd < importedColors.count(); cd++)
-				{
-					m_Doc->PageColors.remove(importedColors[cd]);
-				}
-			}
-			if (importedPatterns.count() != 0)
-			{
-				for (int cd = 0; cd < importedPatterns.count(); cd++)
-				{
-					m_Doc->docPatterns.remove(importedPatterns[cd]);
-				}
-			}
+			for (const auto& importedColor : importedColors)
+				m_Doc->PageColors.remove(importedColor);
+			for (const auto& importedPattern : importedPatterns)
+				m_Doc->docPatterns.remove(importedPattern);
 		}
 		f.close();
 	}
@@ -984,27 +971,28 @@ void PctPlug::parsePict(QDataStream &ts)
 					break;
 				case 0x00FF:		// End of Pict
 					handleLineModeEnd();
-					if (imageData.size() > 0)
+					if (!imageData.isEmpty())
 					{
 						QImage image;
 						image.loadFromData(imageData);
 						image = image.convertToFormat(QImage::Format_ARGB32);
 						int z = m_Doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified, baseX, baseY, image.width() * resX, image.height() * resY, 0, m_Doc->itemToolPrefs().imageFillColor, CommonStrings::None);
 						PageItem *ite = m_Doc->Items->at(z);
-						QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
-						tempFile->setAutoRemove(false);
-						tempFile->open();
-						QString fileName = getLongPathName(tempFile->fileName());
-						tempFile->close();
-						ite->isInlineImage = true;
-						ite->isTempFile = true;
-						image.save(fileName, "PNG");
-						ite->moveBy(m_Doc->currentPage()->xOffset(), m_Doc->currentPage()->yOffset());
-						ite->moveBy(offsetX, offsetY);
-						finishItem(ite);
-						m_Doc->loadPict(fileName, ite);
-						ite->setImageScalingMode(false, false);
-						delete tempFile;
+						QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
+						if (tempFile.open())
+						{
+							QString fileName = getLongPathName(tempFile.fileName());
+							tempFile.setAutoRemove(false);
+							tempFile.close();
+							ite->isInlineImage = true;
+							ite->isTempFile = true;
+							image.save(fileName, "PNG");
+							ite->moveBy(m_Doc->currentPage()->xOffset(), m_Doc->currentPage()->yOffset());
+							ite->moveBy(offsetX, offsetY);
+							finishItem(ite);
+							m_Doc->loadPict(fileName, ite);
+							ite->setImageScalingMode(false, false);
+						}
 					}
 //					qDebug() << "End of Pict";
 					return;
@@ -1031,7 +1019,7 @@ void PctPlug::parsePict(QDataStream &ts)
 		if (progressDialog)
 		{
 			progressDialog->setProgress("GI", ts.device()->pos());
-			qApp->processEvents();
+			QApplication::processEvents();
 		}
 	}
 }
@@ -1219,7 +1207,7 @@ void PctPlug::handlePolygon(QDataStream &ts, quint16 opCode)
 		ite->PoLine.translate(baseX, baseY);
 		ite->PoLine.translate(offsetX, offsetY);
 		finishItem(ite);
-		if ((patternMode) && (opCode != 0x0070))
+		if (patternMode && (opCode != 0x0070))
 			setFillPattern(ite);
 	}
 }
@@ -1296,7 +1284,7 @@ void PctPlug::handleShape(QDataStream &ts, quint16 opCode)
 	if (opCode > 0x0044)
 		currRectType = 1;
 	finishItem(ite);
-	if ((patternMode) && (opCode != 0x0030) && (opCode != 0x0040) && (opCode != 0x0050))
+	if (patternMode && (opCode != 0x0030) && (opCode != 0x0040) && (opCode != 0x0050))
 		setFillPattern(ite);
 }
 
@@ -1381,7 +1369,7 @@ void PctPlug::handleSameShape(QDataStream &ts, quint16 opCode)
 		ite->PoLine.translate(offsetX, offsetY);
 		finishItem(ite);
 	}
-	if ((patternMode) && (opCode != 0x0038) && (opCode != 0x0048) && (opCode != 0x0058))
+	if (patternMode && (opCode != 0x0038) && (opCode != 0x0048) && (opCode != 0x0058))
 		setFillPattern(ite);
 }
 
@@ -1471,7 +1459,7 @@ void PctPlug::handleDHText(QDataStream &ts)
 	if (!textIsPostScript)
 	{
 		QPoint s = currentPointT;
-		currentPointT = QPoint(s.x()+dh * resX, s.y());
+		currentPointT = QPoint(s.x() + dh * resX, s.y());
 		createTextPath(text);
 //		qDebug() << "Handle DH Text at" << currentPointT << text;
 	}
@@ -1489,7 +1477,7 @@ void PctPlug::handleDVText(QDataStream &ts)
 	if (!textIsPostScript)
 	{
 		QPoint s = currentPointT;
-		currentPointT = QPoint(s.x(), s.y()+dv * resY);
+		currentPointT = QPoint(s.x(), s.y() + dv * resY);
 		createTextPath(text);
 //		qDebug() << "Handle DV Text at" << currentPointT << text;
 	}
@@ -1507,7 +1495,7 @@ void PctPlug::handleDHVText(QDataStream &ts)
 	if (!textIsPostScript)
 	{
 		QPoint s = currentPointT;
-		currentPointT = QPoint(s.x()+dh * resX, s.y()+dv * resY);
+		currentPointT = QPoint(s.x() + dh * resX, s.y() + dv * resY);
 		createTextPath(text);
 //		qDebug() << "Handle DHV Text" << dh << dv << "->" << currentPointT << text;
 	}
@@ -1584,14 +1572,14 @@ void PctPlug::handleShortLine(QDataStream &ts)
 		currentPoint = QPoint(x * resX, y * resY);
 		return;
 	}
-	QPoint s = QPoint(x * resX, y * resY);
+	QPoint s(x * resX, y * resY);
 	if (currentPoint != s)
 	{
 		handleLineModeEnd();
 		Coords.svgMoveTo(x * resX, y * resY);
 	}
-	Coords.svgLineTo((x+dh) * resX, (y+dv) * resY);
-	currentPoint = QPoint((x+dh) * resX, (y+dv) * resY);
+	Coords.svgLineTo((x + dh) * resX, (y + dv) * resY);
+	currentPoint = QPoint((x + dh) * resX, (y + dv) * resY);
 	lineMode = true;
 //	qDebug() << "Handle Short Line" << x << y << "+" << dh << dv << "->" << currentPoint;
 }
@@ -1605,8 +1593,8 @@ void PctPlug::handleShortLineFrom(QDataStream &ts)
 	QPoint s = currentPoint;
 	if (Coords.empty())
 		Coords.svgMoveTo(s.x(), s.y());
-	Coords.svgLineTo(s.x()+dh * resX, s.y()+dv * resY);
-	currentPoint = QPoint(s.x()+dh * resX, s.y()+dv * resY);
+	Coords.svgLineTo(s.x() + dh * resX, s.y() + dv * resY);
+	currentPoint = QPoint(s.x() + dh * resX, s.y() + dv * resY);
 	lineMode = true;
 //	qDebug() << "Handle Short Line from" << dh << dv << "->" << currentPoint;
 }
@@ -1616,7 +1604,7 @@ void PctPlug::handleLine(QDataStream &ts)
 	qint16 x1, x2, y1, y2;
 	ts >> y1 >> x1;
 	ts >> y2 >> x2;
-	QPoint s = QPoint(x1 * resX, y1 * resY);
+	QPoint s(x1 * resX, y1 * resY);
 	if (currentPoint != s)
 	{
 		handleLineModeEnd();
@@ -1753,7 +1741,7 @@ void PctPlug::handlePixmap(QDataStream &ts, quint16 opCode)
 				{
 					if (component_size == 4)
 					{
-						uchar *q = (uchar*)(image.scanLine(rr));
+						uchar *q = image.scanLine(rr);
 						for (int xx = 0; xx < img.size(); xx++)
 						{
 							uchar i = (img[xx] >> 4) & 0x0F;
@@ -1820,26 +1808,27 @@ void PctPlug::handlePixmap(QDataStream &ts, quint16 opCode)
 		isPixmap = true;
 		imageData.resize(0);
 	}
-	if ((component_size == 24) || (component_size == 8) || (component_size == 1) || (component_size == 5) || (component_size == 4) || (!isPixmap) || (skipOpcode))
+	if ((component_size == 24) || (component_size == 8) || (component_size == 1) || (component_size == 5) || (component_size == 4) || !isPixmap || skipOpcode)
 	{
 		image = image.convertToFormat(QImage::Format_ARGB32);
 		if (!isPixmap)
 			image.invertPixels();
 		int z = m_Doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified, baseX + dstRect.left() * resX, baseY + dstRect.top() * resY, imgCols * resY, imgRows * resY, 0, m_Doc->itemToolPrefs().imageFillColor, m_Doc->itemToolPrefs().imageStrokeColor);
 		PageItem *ite = m_Doc->Items->at(z);
-		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
-		tempFile->setAutoRemove(false);
-		tempFile->open();
-		QString fileName = getLongPathName(tempFile->fileName());
-		tempFile->close();
-		delete tempFile;
-		ite->isInlineImage = true;
-		ite->isTempFile = true;
-		image.save(fileName, "PNG");
+		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
+		if (tempFile.open())
+		{
+			QString fileName = getLongPathName(tempFile.fileName());
+			tempFile.setAutoRemove(false);
+			tempFile.close();
+			ite->isInlineImage = true;
+			ite->isTempFile = true;
+			image.save(fileName, "PNG");
+			m_Doc->loadPict(fileName, ite);
+		}
 		ite->moveBy(baseX, baseY);
 		ite->moveBy(offsetX, offsetY);
 		finishItem(ite);
-		m_Doc->loadPict(fileName, ite);
 		ite->setImageScalingMode(false, false);
 		skipOpcode = false;
 	}
@@ -2161,40 +2150,41 @@ void PctPlug::setFillPattern(PageItem* ite)
 		image.setColorTable(colors);
 		for (int rr = 0; rr < 8; rr++)
 		{
-			uchar *q = (uchar*)(image.scanLine(rr));
+			uchar *q = image.scanLine(rr);
 			*q = patternData[rr];
 		}
 		image = image.convertToFormat(QImage::Format_ARGB32);
 		ScPattern pat(m_Doc);
 		PageItem* newItem = new PageItem_ImageFrame(m_Doc, 0, 0, 1, 1, 0, CommonStrings::None, CommonStrings::None);
-		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
-		tempFile->setAutoRemove(false);
-		tempFile->open();
-		QString fileName = getLongPathName(tempFile->fileName());
-		tempFile->close();
-		delete tempFile;
-		newItem->isInlineImage = true;
-		newItem->isTempFile = true;
-		image.setDotsPerMeterY(2834);
-		image.setDotsPerMeterX(2834);
-		image.save(fileName, "PNG");
-		if (newItem->loadImage(fileName, false, 72, false))
+		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
+		if (tempFile.open())
 		{
-			pat.width = image.width();
-			pat.height = image.height();
-			pat.scaleX = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
-			pat.scaleY = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
-			pat.pattern = newItem->pixm.qImage().copy();
-			newItem->setWidth(pat.pattern.width());
-			newItem->setHeight(pat.pattern.height());
-			newItem->SetRectFrame();
-			newItem->gXpos = 0.0;
-			newItem->gYpos = 0.0;
-			newItem->gWidth = pat.pattern.width();
-			newItem->gHeight = pat.pattern.height();
-			pat.items.append(newItem);
+			QString fileName = getLongPathName(tempFile.fileName());
+			tempFile.setAutoRemove(false);
+			tempFile.close();
+			newItem->isInlineImage = true;
+			newItem->isTempFile = true;
+			image.setDotsPerMeterY(2834);
+			image.setDotsPerMeterX(2834);
+			image.save(fileName, "PNG");
+			if (newItem->loadImage(fileName, false, 72, false))
+			{
+				pat.width = image.width();
+				pat.height = image.height();
+				pat.scaleX = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
+				pat.scaleY = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
+				pat.pattern = newItem->pixm.qImage().copy();
+				newItem->setWidth(pat.pattern.width());
+				newItem->setHeight(pat.pattern.height());
+				newItem->SetRectFrame();
+				newItem->gXpos = 0.0;
+				newItem->gYpos = 0.0;
+				newItem->gWidth = pat.pattern.width();
+				newItem->gHeight = pat.pattern.height();
+				pat.items.append(newItem);
+			}
 		}
-		patternName = "Pattern_"+newItem->itemName();
+		patternName = "Pattern_" + newItem->itemName();
 		patternName = patternName.trimmed().simplified().replace(" ", "_");
 		m_Doc->addPattern(patternName, pat);
 		importedPatterns.append(patternName);
