@@ -20,7 +20,8 @@ class PLUGIN_API ImportPctPlugin : public LoadSavePlugin
 	public:
 		// Standard plugin implementation
 		ImportPctPlugin();
-		virtual ~ImportPctPlugin();
+		~ImportPctPlugin() override;
+
 		/*!
 		\author Franz Schmid
 		\date
@@ -31,7 +32,7 @@ class PLUGIN_API ImportPctPlugin : public LoadSavePlugin
 		const AboutData* getAboutData() const override;
 		void deleteAboutData(const AboutData* about) const override;
 		void languageChange() override;
-		bool fileSupported(QIODevice* file, const QString & fileName=QString()) const override;
+		bool fileSupported(QIODevice* file, const QString& fileName = QString()) const override;
 		bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0) override;
 		QImage readThumbnail(const QString& fileName) override;
 		void addToMainWindowMenu(ScribusMainWindow *) override {};
@@ -44,11 +45,12 @@ class PLUGIN_API ImportPctPlugin : public LoadSavePlugin
 		\param fileName input filename, or QString() to prompt.
 		\retval bool always true
 		 */
-		virtual bool import(QString fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
+		bool importFile(QString fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
 
 	private:
 		void registerFormats();
-		ScrAction* importAction;
+
+		ScrAction* importAction { nullptr };
 };
 
 extern "C" PLUGIN_API int importpct_getPluginAPIVersion();
