@@ -146,11 +146,11 @@ bool ImportPdfPlugin::fileSupported(QIODevice* /* file */, const QString & fileN
 
 bool ImportPdfPlugin::loadFile(const QString & fileName, const FileFormat &, int flags, int /*index*/)
 {
-	// There's only one format to handle, so we just call import(...)
-	return import(fileName, flags);
+	// There's only one format to handle, so we just call importFile(...)
+	return importFile(fileName, flags);
 }
 
-bool ImportPdfPlugin::import(QString fileName, int flags)
+bool ImportPdfPlugin::importFile(QString fileName, int flags)
 {
 	if (!checkFlags(flags))
 		return false;
@@ -193,14 +193,14 @@ bool ImportPdfPlugin::import(QString fileName, int flags)
 		activeTransaction = UndoManager::instance()->beginTransaction(trSettings);
 
 	bool isCleanedFile = false;
-	QString cleanFile = "";
+	QString cleanFile;
 	if (exts.contains(fi.suffix().toLower()))
 	{
 		if (!ScCore->haveGS())
 		{
-			qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-			ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, tr("The Import plugin cannot handle Postscript files"));
-			qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+			QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+			ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, tr("The Import plugin cannot handle PostScript files"));
+			QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 			return false;
 		}
 
@@ -223,18 +223,20 @@ bool ImportPdfPlugin::import(QString fileName, int flags)
 		args.clear();
 		isCleanedFile = true;
 	}
+
 	bool ret = false;
-	PdfPlug *dia = new PdfPlug(m_Doc, flags);
-	Q_CHECK_PTR(dia);
+	auto pdfPlug = std::make_unique<PdfPlug>(m_Doc, flags);
+	Q_CHECK_PTR(pdfPlug.get());
 	if (isCleanedFile)
-		ret = dia->import(cleanFile, trSettings, flags, !(flags & lfScripted));
+		ret = pdfPlug->importFile(cleanFile, trSettings, flags, !(flags & lfScripted));
 	else
-		ret = dia->import(fileName, trSettings, flags, !(flags & lfScripted));
+		ret = pdfPlug->importFile(fileName, trSettings, flags, !(flags & lfScripted));
 	if (activeTransaction)
 		activeTransaction.commit();
 	if (emptyDoc || !(flags & lfInteractive) || !(flags & lfScripted))
 		UndoManager::instance()->setUndoEnabled(true);
-	delete dia;
+	pdfPlug.reset();
+
 	if (isCleanedFile)
 		QFile::remove(cleanFile);
 	return ret;
@@ -244,12 +246,13 @@ QImage ImportPdfPlugin::readThumbnail(const QString& fileName)
 {
 	if (fileName.isEmpty())
 		return QImage();
+
 	UndoManager::instance()->setUndoEnabled(false);
 	m_Doc = nullptr;
-	PdfPlug *dia = new PdfPlug(m_Doc, lfCreateThumbnail);
-	Q_CHECK_PTR(dia);
-	QImage ret = dia->readThumbnail(fileName);
+	auto pdfPlug = std::make_unique<PdfPlug>(m_Doc, lfCreateThumbnail);
+	Q_CHECK_PTR(pdfPlug.get());
+	QImage ret = pdfPlug->readThumbnail(fileName);
 	UndoManager::instance()->setUndoEnabled(true);
-	delete dia;
+
 	return ret;
 }
