@@ -13,14 +13,11 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMessageBox>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 
 #include <cstdlib>
 
 #include "importps.h"
-
-
 #include "commonstrings.h"
 #include "loadsaveplugin.h"
 #include "prefscontext.h"
@@ -37,15 +34,13 @@ for which a new license (GPL+exception) is in place.
 #include "scribusview.h"
 #include "sctextstream.h"
 #include "selection.h"
-#include "ui/customfdialog.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 #include "ui/scmessagebox.h"
 #include "undomanager.h"
 #include "util.h"
 #include "util_color.h"
 #include "util_formats.h"
-#include "util_math.h"
+
 
 #ifdef HAVE_PODOFO
 	#include <podofo/podofo.h>
@@ -62,12 +57,10 @@ EPSPlug::EPSPlug(ScribusDoc* doc, int flags)
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 }
 
-bool EPSPlug::import(QString fName, const TransactionSettings &trSettings, int flags, bool showProgress)
+bool EPSPlug::importFile(QString fName, const TransactionSettings &trSettings, int flags, bool showProgress)
 {
 #ifdef Q_OS_MACOS
-	#if QT_VERSION >= 0x050300
-		showProgress = false;
-	#endif
+	showProgress = false;
 #endif
 
 	bool success = false;
@@ -158,7 +151,7 @@ bool EPSPlug::import(QString fName, const TransactionSettings &trSettings, int f
 		try
 		{
 			PoDoFo::PdfError::EnableDebug( false );
-#if (PODOFO_VERSION == 0 && PODOFO_MINOR > 6)
+#if (PODOFO_VERSION == 0 && PODOFO_MINOR < 10)
 		PoDoFo::PdfError::EnableLogging( false );
 #endif
 #if (PODOFO_VERSION == 0 && PODOFO_MINOR == 5 && PODOFO_REVISION == 99) || PODOFO_MINOR > 5
