@@ -30,7 +30,7 @@ class PLUGIN_API UniconvImportPlugin : public LoadSavePlugin
 		const AboutData* getAboutData() const override;
 		void deleteAboutData(const AboutData* about) const override;
 		void languageChange() override;
-		bool fileSupported(QIODevice* file, const QString & fileName=QString()) const override;
+		bool fileSupported(QIODevice* file, const QString& fileName = QString()) const override;
 		bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0) override;
 		void addToMainWindowMenu(ScribusMainWindow *) override {};
 
@@ -40,7 +40,7 @@ class PLUGIN_API UniconvImportPlugin : public LoadSavePlugin
 		\param filename a file name to import
 		\retval true for success
 		*/
-		virtual bool import(const QString& fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
+		virtual bool importFile(const QString& fileName = QString(), int flags = lfUseCurrentPage|lfInteractive);
 
 	private:
 		void registerFormats();
