@@ -15,6 +15,8 @@ for which a new license (GPL+exception) is in place.
 #include <QColor>
 #include <QList>
 #include <QSize>
+#include <QTextCodec>
+
 #include "pluginapi.h"
 #include "fpointarray.h"
 #include "wmfcontext.h"
@@ -42,7 +44,7 @@ public:
 	WMFImport(ScribusDoc* doc, int flags);
 	~WMFImport();
 
-	bool import(const QString& fname, const TransactionSettings& trSettings, int flags);
+	bool importFile(const QString& fname, const TransactionSettings& trSettings, int flags);
 	QImage readThumbnail(const QString& fn);
 
 	void wmfClosePath(FPointArray *i);
