@@ -29,7 +29,7 @@ class PLUGIN_API WMFImportPlugin : public LoadSavePlugin
 		const AboutData* getAboutData() const override;
 		void deleteAboutData(const AboutData* about) const override;
 		void languageChange() override;
-		bool fileSupported(QIODevice* file, const QString & fileName=QString()) const override;
+		bool fileSupported(QIODevice* file, const QString& fileName = QString()) const override;
 		bool loadFile(const QString & fileName, const FileFormat & fmt, int flags, int index = 0) override;
 		QImage readThumbnail(const QString& fileName) override;
 		void addToMainWindowMenu(ScribusMainWindow *) override {};
@@ -41,7 +41,7 @@ class PLUGIN_API WMFImportPlugin : public LoadSavePlugin
 		\param filename a file name to import
 		\retval true for success
 		 */
-		virtual bool import(QString filename = QString(), int flags = lfUseCurrentPage|lfInteractive);
+		virtual bool importFile(QString filename = QString(), int flags = lfUseCurrentPage|lfInteractive);
 
 	private:
 		void registerFormats();
