@@ -466,7 +466,7 @@ QImage WpgPlug::readThumbnail(const QString& fName)
 	return QImage();
 }
 
-bool WpgPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool WpgPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
