@@ -173,7 +173,7 @@ QImage XpsPlug::readThumbnail(const QString& fName)
 	return tmp;
 }
 
-bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool XpsPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
@@ -1215,7 +1215,7 @@ PageItem* XpsPlug::parseObjectXML(QDomElement &dpg, const QString& path)
 				double dx = 0.0;
 				double dy = 0.0;
 				getTransformValuesFromMatrix( obState.transform, scX, scY, rot, dx, dy);
-				QLineF transp = QLineF(0, 0, retObj->xPos() - m_Doc->currentPage()->xOffset(), retObj->yPos() - m_Doc->currentPage()->yOffset());
+				QLineF transp(0, 0, retObj->xPos() - m_Doc->currentPage()->xOffset(), retObj->yPos() - m_Doc->currentPage()->yOffset());
 				transp = obState.transform.map(transp);
 				retObj->setXYPos(transp.p2().x() + m_Doc->currentPage()->xOffset(), transp.p2().y() + m_Doc->currentPage()->yOffset());
 				if ((scX != 1.0) || (scY != 1.0))
@@ -1689,15 +1689,15 @@ PageItem* XpsPlug::createItem(QDomElement &dpg, ObjState &obState)
 			if (uz->read(obState.imagePath, f))
 			{
 				QFileInfo fi(obState.imagePath);
-				QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_xps_XXXXXX." + fi.suffix());
-				tempFile->setAutoRemove(false);
-				if (tempFile->open())
+				QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_xps_XXXXXX." + fi.suffix());
+				if (tempFile.open())
 				{
-					QString fileName = getLongPathName(tempFile->fileName());
+					QString fileName = getLongPathName(tempFile.fileName());
 					if (!fileName.isEmpty())
 					{
-						tempFile->write(f);
-						tempFile->close();
+						tempFile.setAutoRemove(false);
+						tempFile.write(f);
+						tempFile.close();
 						retObj->isInlineImage = true;
 						retObj->isTempFile = true;
 						retObj->AspectRatio = false;
@@ -1706,7 +1706,6 @@ PageItem* XpsPlug::createItem(QDomElement &dpg, ObjState &obState)
 						retObj->adjustPictScale();
 					}
 				}
-				delete tempFile;
 			}
 		}
 		retObj = m_Doc->Items->takeAt(z);
@@ -1889,14 +1888,12 @@ ScFace XpsPlug::loadFontByName(const QString &fileName)
 	QByteArray fontData;
 	if (!uz->read(fileName, fontData))
 		return t;
-	QTemporaryFile *tempImageFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_zip_XXXXXX.dat");
-	if (tempImageFile == nullptr)
+	QTemporaryFile tempImageFile(QDir::tempPath() + "/scribus_temp_zip_XXXXXX.dat");
+	if (!tempImageFile.open())
 		return t;
-	tempImageFile->setAutoRemove(false);
-	tempImageFile->open();
-	QString fname = getLongPathName(tempImageFile->fileName());
-	tempImageFile->close();
-	delete tempImageFile;
+	QString fname = getLongPathName(tempImageFile.fileName());
+	tempImageFile.setAutoRemove(false);
+	tempImageFile.close();
 	tempFontFiles.append(fname);
 	QFileInfo fi(fileName);
 	QString ext = fi.suffix().toLower();
