@@ -12,7 +12,6 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMessageBox>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -22,34 +21,18 @@ for which a new license (GPL+exception) is in place.
 #include <libzmf/libzmf.h>
 
 #include "commonstrings.h"
-#include "ui/customfdialog.h"
-#include "fileloader.h"
 #include "loadsaveplugin.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "ui/propertiespalette.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scpattern.h"
 #include "scribus.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusview.h"
-#include "sctextstream.h"
 #include "selection.h"
 #include "undomanager.h"
-#include "util.h"
-#include "util_formats.h"
-#include "util_math.h"
 
 extern SCRIBUS_API ScribusQApp * ScQApp;
 
@@ -61,7 +44,7 @@ ZmfPlug::ZmfPlug(ScribusDoc* doc, int flags)
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 }
 
-QImage ZmfPlug::readThumbnail(QString fName)
+QImage ZmfPlug::readThumbnail(const QString& fName)
 {
 	QFileInfo fi(fName);
 	double b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
@@ -120,15 +103,14 @@ QImage ZmfPlug::readThumbnail(QString fName)
 	return QImage();
 }
 
-bool ZmfPlug::import(QString fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool ZmfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
-	QString fName = fNameIn;
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
 	bool ret = false;
-	QFileInfo fi(fName);
+	QFileInfo fi(fNameIn);
 	if (!ScCore->usingGUI())
 	{
 		interactive = false;
@@ -214,7 +196,7 @@ bool ZmfPlug::import(QString fNameIn, const TransactionSettings& trSettings, int
 	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
-	if (convert(fName))
+	if (convert(fNameIn))
 	{
 		tmpSel->clear();
 		QDir::setCurrent(CurDirP);
@@ -319,13 +301,12 @@ ZmfPlug::~ZmfPlug()
 	delete tmpSel;
 }
 
-bool ZmfPlug::convert(QString fn)
+bool ZmfPlug::convert(const QString& fn)
 {
 	importedColors.clear();
 	importedPatterns.clear();
 
-	QFile file(fn);
-	if (!file.exists())
+	if (!QFile::exists(fn))
 	{
 		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist";
 		return false;
