@@ -16,6 +16,8 @@ This program is free software - see LICENSE file in the distribution
 or documentation
 */
 
+#include <memory>
+
 #include <QProgressBar>
 #include <QRegularExpression>
 
@@ -33,10 +35,7 @@ or documentation
 #include "version.h"
 
 
-SWParse::SWParse()
-{
-	modify = 0;
-}
+SWParse::SWParse() = default;
 
 void SWParse::parseItem(PageItem *aFrame)
 {
@@ -47,14 +46,17 @@ void SWParse::parseItem(PageItem *aFrame)
 	// the content of the frame - text itself
 	QString content;
 	int changes = 0;
-	// list of the short words
-	QStringList shorts;
 	// text with special space
 	QString unbreak;
 	// the regexp
 	QRegularExpression rx(" ");
 	// cfg
-	SWConfig *cfg = new SWConfig();
+	auto cfg = std::make_unique<SWConfig>();
+
+	// use character unicode properties when matching expression
+	auto patternOptions = rx.patternOptions();
+	patternOptions |= QRegularExpression::UseUnicodePropertiesOption;
+	rx.setPatternOptions(patternOptions);
 
 	// an ugly hack to get the language code from the item language property
 	if (lang.isEmpty())
@@ -65,22 +67,22 @@ void SWParse::parseItem(PageItem *aFrame)
 	}
 
 	// apply spaces after shorts
-	shorts = cfg->getShortWords(lang);
-	if (shorts.count()==0)
+	QStringList shorts = cfg->getShortWords(lang);
+	if (shorts.isEmpty())
 		return; // no changes
 
 	// get text from frame
 	int i;
-	for (i=0; i < aFrame->itemText.length() && ! aFrame->frameDisplays(i); ++i)
+	for (i = 0; i < aFrame->itemText.length() && !aFrame->frameDisplays(i); ++i)
 		;
 	for (; i < aFrame->itemText.length() && aFrame->frameDisplays(i); ++i)
 		content += aFrame->itemText.text(i,1);
 	changes = content.count(SpecialChars::NBSPACE);
 
 	// for every config string, replace its spaces by nbsp's.
-	for (QStringList::Iterator it = shorts.begin(); it != shorts.end(); ++it)
+	for (const QString& shortWord : shorts)
 	{
-		unbreak = (*it);
+		unbreak = shortWord;
 		// replace ' ' from cfg with '~' in the replacement string
 		unbreak.replace(SPACE, SpecialChars::NBSPACE);
 		/*
@@ -102,7 +104,7 @@ void SWParse::parseItem(PageItem *aFrame)
 			- "» !" : '«' is matched by \W before, newline is
 			matched by \W after.
 		*/
-		rx.setPattern("(\\b|\\W)" + rx.escape(*it) + "(\\b|\\W)");
+		rx.setPattern("(\\b|\\W)" + QRegularExpression::escape(shortWord) + "(\\b|\\W)");
 		/*
 		QString::replace works on the whole string in one pass.
 		On every occurrence of our regexp, \1 and \2 are replaced
@@ -112,23 +114,21 @@ void SWParse::parseItem(PageItem *aFrame)
 		content.replace(rx, "\\1" + unbreak + "\\2");
 	}
 	// return text into frame
-	for (i=0; i < aFrame->itemText.length() && ! aFrame->frameDisplays(i); ++i)
+	for (i = 0; i < aFrame->itemText.length() && !aFrame->frameDisplays(i); ++i)
 		;
 	for (; i < aFrame->itemText.length() && aFrame->frameDisplays(i); ++i)
 		aFrame->itemText.replaceChar(i, content.at(i));
 	if (content.count(SpecialChars::NBSPACE) > changes)
 		++modify;
-
-	delete(cfg);
 } // end of method
 
 void SWParse::parseSelection(ScribusDoc* doc)
 {
-	uint docSelectionCount = doc->m_Selection->count();
+	int docSelectionCount = doc->m_Selection->count();
 	if (docSelectionCount == 0)
 		return;
 	doc->scMW()->mainWindowProgressBar->setMaximum(docSelectionCount);
-	for (uint i=0; i < docSelectionCount; ++i)
+	for (int i = 0; i < docSelectionCount; ++i)
 	{
 		doc->scMW()->mainWindowProgressBar->setValue(i);
 		parseItem(doc->m_Selection->itemAt(i));
@@ -144,21 +144,21 @@ void SWParse::parsePage(ScribusDoc* doc)
 
 void SWParse::parsePage(ScribusDoc* doc, int page)
 {
-	uint count = 0;
-	uint docItemsCount = doc->Items->count();
+	int count = 0;
+	int docItemsCount = doc->Items->count();
 	if (docItemsCount == 0)
 		return;
 
-	for (uint i = 0; i < docItemsCount; ++i)
+	for (int i = 0; i < docItemsCount; ++i)
 	{
-		PageItem* pi = doc->Items->at(i);
+		const PageItem* pi = doc->Items->at(i);
 		if (pi->OwnPage == page)
 			++count;
 	}
 	doc->scMW()->mainWindowProgressBar->setMaximum(count);
 	doc->view()->GotoPage(page);
-	uint j = 0;
-	for (uint i = 0; i < docItemsCount; ++i)
+	int j = 0;
+	for (int i = 0; i < docItemsCount; ++i)
 	{
 		PageItem* pi = doc->Items->at(i);
 		if (pi->OwnPage == page)
@@ -172,6 +172,6 @@ void SWParse::parsePage(ScribusDoc* doc, int page)
 
 void SWParse::parseAll(ScribusDoc* doc)
 {
-	for (int i=0; i < doc->Pages->count(); ++i)
+	for (int i = 0; i < doc->Pages->count(); ++i)
 		parsePage(doc, i);
 }
