@@ -1224,7 +1224,7 @@ void SCFonts::readFontCache(const QString& pf)
 	struct testCache foCache;
 
 	QDomDocument docu("fontcacherc");
-	QFile f(pf + "/checkfonts170.xml");
+	QFile f(pf + "/checkfonts172.xml");
 	if (!f.open(QIODevice::ReadOnly))
 		return;
 	ScCore->setSplashStatus( QObject::tr("Reading Font Cache") );
@@ -1301,7 +1301,7 @@ void SCFonts::writeFontCache(const QString& pf) const
 
 	ScCore->setSplashStatus( QObject::tr("Writing updated Font Cache") );
 
-	QFile file(pf + "/checkfonts170.xml");
+	QFile file(pf + "/checkfonts172.xml");
 	if (!file.open(QIODevice::WriteOnly))
 		return;
 	QTextStream s(&file);
@@ -1355,6 +1355,106 @@ void SCFonts::getFonts(const QString& pf, bool showFontInfo)
 	writeFontCache(pf);
 }
 
+QString SCFonts::getRegularStyle(const QString& family)
+{
+	auto itFamily = styleCache.find(family);
+	if (itFamily == styleCache.end())
+		itFamily = styleCache.insert(family, {});
+
+	auto itStyle = itFamily->constFind(StyleType::Regular);
+	if (itStyle != itFamily->constEnd())
+		return itStyle.value();
+
+	QString style;
+	QStringList styles = fontMap.value(family, {});
+	if (!styles.isEmpty())
+		style = styles[0];
+	if (styles.contains("Regular"))
+		style = "Regular";
+	else if (styles.contains("Roman"))
+		style = "Roman";
+	else if (styles.contains("Medium"))
+		style = "Medium";
+	else if (styles.contains("Book"))
+		style = "Book";
+	itFamily->insert(StyleType::Regular, style);
+
+	return style;
+}
+
+/*
+ * TODO:
+ * - how to transition:
+ *   - from "Condensed" to "Condensed Bold"?
+ *   - from "Light" to "Regular"?
+ *   - from "Bold" to "Black"?
+ */
+QString SCFonts::getBoldStyle(const QString& family)
+{
+	auto itFamily = styleCache.find(family);
+	if (itFamily == styleCache.end())
+		itFamily = styleCache.insert(family, {});
+
+	auto itStyle = itFamily->constFind(StyleType::Bold);
+	if (itStyle != itFamily->constEnd())
+		return itStyle.value();
+
+	QString style;
+	QStringList styles = fontMap.value(family, {});
+	if (styles.contains("Bold"))
+		style = "Bold";
+	else if (styles.contains("Black"))
+		style = "Black";
+	itFamily->insert(StyleType::Bold, style);
+
+	return style;
+}
+
+QString SCFonts::getBoldItalicStyle(const QString& family)
+{
+	auto itFamily = styleCache.find(family);
+	if (itFamily == styleCache.end())
+		itFamily = styleCache.insert(family, {});
+
+	auto itStyle = itFamily->constFind(StyleType::BoldItalic);
+	if (itStyle != itFamily->constEnd())
+		return itStyle.value();
+
+	QString style;
+	QString bold = getBoldStyle(family);
+	QString italic = getItalicStyle(family);
+	if (bold.isEmpty())
+		style = italic;
+	else if  (italic.isEmpty())
+		style = bold;
+	else
+		style = bold + " " + italic;
+	itFamily->insert(StyleType::BoldItalic, style);
+
+	return style;
+}
+
+QString SCFonts::getItalicStyle(const QString& family)
+{
+	auto itFamily = styleCache.find(family);
+	if (itFamily == styleCache.end())
+		itFamily = styleCache.insert(family, {});
+
+	auto itStyle = itFamily->constFind(StyleType::Italic);
+	if (itStyle != itFamily->constEnd())
+		return itStyle.value();
+
+	QString style;
+	QStringList styles = fontMap.value(family, {});
+	if (styles.contains("Italic"))
+		style = "Italic";
+	else if (styles.contains("Oblique"))
+		style = "Oblique";
+	itFamily->insert(StyleType::Italic, style);
+
+	return style;
+}
+
 void SCFonts::addRejectedFont(const QString& fontPath, const QString& message)
 {
 	rejectedFonts.insert(fontPath, message);
