@@ -18,19 +18,20 @@ for which a new license (GPL+exception) is in place.
 *                                                                         *
 ***************************************************************************/
 
-#include <QCryptographicHash>
-#include <QXmlStreamWriter>
-#include <QXmlStreamReader>
 #include <QByteArray>
+#include <QByteArrayView>
+#include <QCryptographicHash>
 #include <QDateTime>
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
+#include <QXmlStreamReader>
+#include <QXmlStreamWriter>
 
-#include "sclockedfile.h"
-#include "scimagecacheproxy.h"
 #include "scimagecachemanager.h"
+#include "scimagecacheproxy.h"
 #include "scimagecachewriteaction.h"
+#include "sclockedfile.h"
 #include "scpaths.h"
 #include "util_file.h"
 
@@ -141,17 +142,17 @@ bool ScImageCacheProxy::loadMetadata(ScLockedFile *file, MetaMap *meta, MetaMap
 		{
 			QXmlStreamAttributes attr = xml.attributes();
 
-			if (xml.name() == "cache")
+			if (xml.name() == QLatin1String("cache"))
 			{
-				if (attr.hasAttribute("base"))
+				if (attr.hasAttribute(QLatin1String("base")))
 				{
 					if (base)
-						*base = attr.value("base").toString();
+						*base = attr.value(QLatin1String("base")).toString();
 
 					baseFound = true;
 				}
 			}
-			else if (xml.name() == "metadata")
+			else if (xml.name() == QLatin1String("metadata"))
 			{
 				if (meta)
 				{
@@ -163,7 +164,7 @@ bool ScImageCacheProxy::loadMetadata(ScLockedFile *file, MetaMap *meta, MetaMap
 
 				metaFound = true;
 			}
-			else if (xml.name() == "modifier")
+			else if (xml.name() == QLatin1String("modifier"))
 			{
 				if (mod)
 				{
@@ -175,7 +176,7 @@ bool ScImageCacheProxy::loadMetadata(ScLockedFile *file, MetaMap *meta, MetaMap
 
 				modFound = true;
 			}
-			else if (xml.name() == "imginfo")
+			else if (xml.name() == QLatin1String("imginfo"))
 			{
 				if (info)
 				{
@@ -310,7 +311,10 @@ QString ScImageCacheProxy::imageBaseName(const QImage & image) const
 	}
 	QCryptographicHash hash(HASH_ALGORITHM);
 	for (int i = 0; i < image.height(); i++)
-		hash.addData(reinterpret_cast<const char *>(image.scanLine(i)), image.bytesPerLine());
+	{
+		QByteArrayView baView(image.scanLine(i), image.bytesPerLine());
+		hash.addData(baView);
+	}
 	return addDirLevels(hash.result().toHex()) + "-" + m_metadata["size"];
 }
 
@@ -602,7 +606,7 @@ bool ScImageCacheProxy::loadRef(ScLockedFile *file, int & refcount)
 		{
 			QXmlStreamAttributes attr = xml.attributes();
 
-			if (xml.name() == "reference")
+			if (xml.name() == QLatin1String("reference"))
 				if (attr.hasAttribute("count"))
 					refcount = attr.value("count").toString().toInt(&refcountFound);
 		}
