@@ -279,6 +279,7 @@ class SCRIBUS_API ScActionPlugin : public ScPlugin
 											// for the Plugin Action to be enabled
 			bool enabledOnStartup {false};
 			bool enabledForStoryEditor {false};
+			bool exportPlugin {false};
 			QString seMenu;
 			QString seParentMenu;
 			QString seKeySequence;
@@ -445,7 +446,7 @@ class SCRIBUS_API ScActionPlugin : public ScPlugin
  *
  * Such plug-ins have an init method and a cleanup method; they have
  * no "run" method as such. It is up to the plugin to determine how
- * best to interfact with the user.
+ * best to interact with the user.
  */
 class SCRIBUS_API ScPersistentPlugin : public ScPlugin
 {
