@@ -41,4 +41,4 @@ ATTRDEF(QString, fontVariant, FontVariant, "", true)
 ATTRDEF(ScFace, font, Font, ScFace::none(), true)
 ATTRDEF(QStringList, features, Features, QStringList(CharStyle::INHERIT), false)
 ATTRDEF(int, hyphenWordMin, HyphenWordMin, 3, false)
-ATTRDEF(uint, hyphenChar, HyphenChar, 0x2010, false)
+ATTRDEF(char32_t, hyphenChar, HyphenChar, 0x2010, false)
