@@ -101,7 +101,8 @@ StoryText::~StoryText()
 		doc->charStyles().disconnect(this, SLOT(invalidateAll()));
 	} */
 	d->refs--;
-	if (d->refs == 0) {
+	if (d->refs == 0)
+	{
 		d->clear();
 		d->len = 0;
 		delete d;
@@ -231,7 +232,7 @@ void StoryText::normalizeCursorPosition()
 	d->cursorPosition = qMax((uint) 0, qMin(d->cursorPosition, d->len));
 }
 
-int StoryText::normalizedCursorPosition()
+int StoryText::normalizedCursorPosition() const
 {
 	return (int) qMax((uint) 0, qMin(d->cursorPosition, d->len));
 }
@@ -579,9 +580,6 @@ void StoryText::insertParSep(int pos)
 			applyStyle(pos, d->trailingStyle);
 			d->trailingStyle.erase();
 		}
-//		it->parstyle->setName("para"); // DON'T TRANSLATE
-//		it->parstyle->charStyle().setName("cpara"); // DON'T TRANSLATE
-//		it->parstyle->charStyle().setContext( d->defaultStyle.charStyleContext() );
 	}
 	d->replaceCharStyleContextInParagraph(pos, it->parstyle->charStyleContext());
 }
@@ -594,9 +592,6 @@ void StoryText::removeParSep(int pos)
 	ScText* it = item(pos);
 	if (it->parstyle)
 	{
-//		const CharStyle* oldP = & it->parstyle->charStyle();
-//		const CharStyle* newP = & that->paragraphStyle(pos+1).charStyle();
-//		d->replaceParentStyle(pos, oldP, newP);
 		delete it->parstyle;
 		it->parstyle = nullptr;
 	}
@@ -701,7 +696,7 @@ void StoryText::insertChars(int pos, const QString& txt, bool applyNeighbourStyl
 	assert(pos >= 0);
 	assert(pos <= length());
 	
-	if (txt.length() == 0)
+	if (txt.isEmpty())
 		return;
 	
 	const StyleContext* cStyleContext = paragraphStyle(pos).charStyleContext();
@@ -744,7 +739,7 @@ void StoryText::insertCharsWithSoftHyphens(int pos, const QString& txt, bool app
 	assert(pos >= 0);
 	assert(pos <= length());
 	
-	if (txt.length() == 0)
+	if (txt.isEmpty())
 		return;
 	
 	const StyleContext* cStyleContext = paragraphStyle(pos).charStyleContext();
@@ -853,7 +848,7 @@ void StoryText::replaceSelection(const QString& newText)
 	}
 
 	deselectAll();
-	if (newText.length() > 0)
+	if (!newText.isEmpty())
 		select(selStart, newText.length());
 	setCursorPosition(selStart + newText.length());
 }
@@ -948,12 +943,21 @@ void StoryText::replaceObject(int pos, int ob)
 	m_doc->FrameItems[ob]->OwnPage = -1; // #10379: OwnPage is not meaningful for inline object
 }
 
-
 int StoryText::length() const
 {
 	return d->len;
 }
 
+bool StoryText::isEmpty() const
+{
+	return (d->len == 0);
+}
+
+bool StoryText::isNotEmpty() const
+{
+	return (d->len > 0);
+}
+
 QString StoryText::plainText() const
 {
 	if (length() <= 0)
@@ -1059,7 +1063,7 @@ ExpansionPoint StoryText::expansionPoint(int pos) const
 }
 
 
-QString StoryText::sentence(int pos, int &posn)
+QString StoryText::sentence(int pos, int &posn) const
 {
 	int sentencePos = qMax(0, prevSentence(pos));
 	posn = sentencePos;
@@ -1067,7 +1071,7 @@ QString StoryText::sentence(int pos, int &posn)
 	return text(sentencePos, nextSentencePos - sentencePos);
 }
 
-QString StoryText::word(int pos)
+QString StoryText::word(int pos) const
 {
 	BreakIterator* it = getWordIterator();
 	if (it)
@@ -1287,7 +1291,7 @@ LayoutFlags StoryText::flags(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	return  static_cast<LayoutFlags>(d->at(pos)->effects().value & ScStyle_NonUserStyles);
+	return static_cast<LayoutFlags>(d->at(pos)->effects().value & ScStyle_NonUserStyles);
 }
 
 bool StoryText::hasFlag(int pos, LayoutFlags flags) const
@@ -1339,7 +1343,7 @@ const CharStyle & StoryText::charStyle(int pos) const
 	assert(pos >= 0);
 	assert(pos <= length());
 
-	if (length() == 0)
+	if (this->isEmpty())
 	{
 //		qDebug() << "storytext::charstyle: default";
 		return d->orphanedCharStyle;
@@ -1395,9 +1399,6 @@ const ParagraphStyle & StoryText::paragraphStyle(int pos) const
 		qDebug("inserting default parstyle at %i", pos);
 		current->parstyle = new ParagraphStyle();
 		current->parstyle->setContext( & d->pstyleContext);
-//		current->parstyle->setName( "para(paragraphStyle)" ); // DON'T TRANSLATE
-//		current->parstyle->charStyle().setName( "cpara(paragraphStyle)" ); // DON'T TRANSLATE
-//		current->parstyle->charStyle().setContext( d->defaultStyle.charStyleContext());
 	}
 	else
 	{
@@ -1417,16 +1418,8 @@ const ParagraphStyle& StoryText::defaultStyle() const
 void StoryText::setDefaultStyle(const ParagraphStyle& style)
 {
 	const StyleContext * oldPContext = d->defaultStyle.context();
-//	const StyleContext * oldCContext = d->defaultStyle.charStyle().context();
 	d->defaultStyle = style;
 	d->defaultStyle.setContext( oldPContext );
-//	d->defaultStyle.setName( "storydefault" ); // DON'T TRANSLATE
-//	d->defaultStyle.charStyle().setName( "cstorydefault" ); // DON'T TRANSLATE
-//	qDebug() << QString("defstyle %1 context %2 defcstyle %3 ccontext %4 newcontext %5")
-//		   .arg((uint)&d->defaultStyle,16).arg((uint)oldPContext,16)
-//		   .arg((uint)&d->defaultStyle.charStyle(),16).arg((uint)oldCContext,16)
-//		   .arg((uint)d->defaultStyle.charStyle().context(),16);
-//	d->defaultStyle.charStyle().setContext( oldCContext );
 	invalidateAll();
 }
 
@@ -1525,9 +1518,6 @@ void StoryText::applyStyle(int pos, const ParagraphStyle& style, bool rmDirectFo
 			qDebug("PARSEP without style at pos %i", i);
 			d->at(i)->parstyle = new ParagraphStyle();
 			d->at(i)->parstyle->setContext( & d->pstyleContext);
-//			d->at(i)->parstyle->setName( "para(applyStyle)" ); // DON'T TRANSLATE
-//			d->at(i)->parstyle->charStyle().setName( "cpara(applyStyle)" ); // DON'T TRANSLATE
-//			d->at(i)->parstyle->charStyle().setContext( d->defaultStyle.charStyleContext() );
 		}
 //		qDebug() << QString("applying parstyle %2 at %1 for %3").arg(i).arg(paragraphStyle(pos).name()).arg(pos);
 		d->at(i)->parstyle->applyStyle(style);
@@ -1569,9 +1559,6 @@ void StoryText::eraseStyle(int pos, const ParagraphStyle& style)
 			qDebug("PARSEP without style at pos %i", i);
 			d->at(i)->parstyle = new ParagraphStyle();
 			d->at(i)->parstyle->setContext( & d->pstyleContext);
-//			d->at(i)->parstyle->setName( "para(eraseStyle)" ); // DON'T TRANSLATE
-//			d->at(i)->parstyle->charStyle().setName( "cpara(eraseStyle)" ); // DON'T TRANSLATE
-//			d->at(i)->parstyle->charStyle().setContext( d->defaultStyle.charStyleContext());
 		}
 		//		qDebug() << QString("applying parstyle %2 at %1 for %3").arg(i).arg(paragraphStyle(pos).name()).arg(pos);
 		d->at(i)->parstyle->eraseStyle(style);
@@ -1670,7 +1657,7 @@ void StoryText::replaceCharStyles(const QMap<QString,QString>& newNameForOld)
 
 void StoryText::fixLegacyFormatting()
 {
-	if (length() == 0)
+	if (this->isEmpty())
 		return;
 
 	for (int i = 0; i < length(); ++ i)
@@ -1683,7 +1670,7 @@ void StoryText::fixLegacyFormatting()
 
 void StoryText::fixLegacyFormatting(int pos)
 {
-	if (length() == 0)
+	if (this->isEmpty())
 		return;
 
 	if (pos < 0)
@@ -1756,7 +1743,9 @@ int StoryText::startOfParagraph(uint index) const
 
 	for (int i = 0; i < length(); ++i)
 	{
-		if (d->at(i)->ch == SpecialChars::PARSEP && ! --index)
+		if (d->at(i)->ch != SpecialChars::PARSEP)
+			continue;
+		if (--index == 0)
 			return i + 1;
 	}
 	return length();
@@ -1780,7 +1769,9 @@ int StoryText::endOfParagraph(uint index) const
 	++index;
 	for (int i = 0; i < length(); ++i)
 	{
-		if (d->at(i)->ch == SpecialChars::PARSEP && ! --index)
+		if (d->at(i)->ch != SpecialChars::PARSEP)
+			continue;
+		if (--index == 0)
 			return i;
 	}
 	return length();
@@ -1803,21 +1794,21 @@ int StoryText::endOfRun(uint index) const
 
 // positioning. all positioning methods return char positions
 
-int StoryText::nextChar(int pos)
+int StoryText::nextChar(int pos) const
 {
 	if (pos < length())
 		return pos + 1;
 	return length();
 }
 
-int StoryText::prevChar(int pos)
+int StoryText::prevChar(int pos) const
 {
 	if (pos > 0)
 		return pos - 1;
 	return 0;
 }
 
-int StoryText::firstWord()
+int StoryText::firstWord() const
 {
 	int len = length();
 	int pos = 0;
@@ -1831,7 +1822,7 @@ int StoryText::firstWord()
 	return pos;
 }
 
-int StoryText::nextWord(int pos)
+int StoryText::nextWord(int pos) const
 {
 	BreakIterator* it = getWordIterator();
 	if (!it)
@@ -1849,7 +1840,7 @@ int StoryText::nextWord(int pos)
 	return pos;
 }
 
-int StoryText::prevWord(int pos)
+int StoryText::prevWord(int pos) const
 {
 	BreakIterator* it = getWordIterator();
 	if (!it)
@@ -1873,6 +1864,10 @@ int StoryText::endOfWord(int pos) const
 	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
 	it->setText(unicodeStr);
 
+	// The provided position is already at the limit of a word
+	if (it->isBoundary(pos) && (text(pos).isSpace() || text(pos).isPunct()))
+		return pos;
+
 	pos = it->following(pos);
 	return pos;
 }
@@ -1891,7 +1886,7 @@ int StoryText::endOfSentence(int pos) const
 	return end;
 }
 
-int StoryText::nextSentence(int pos)
+int StoryText::nextSentence(int pos) const
 {
 	BreakIterator* it = getSentenceIterator();
 	if (!it)
@@ -1906,7 +1901,7 @@ int StoryText::nextSentence(int pos)
 	return pos;
 }
 
-int StoryText::prevSentence(int pos)
+int StoryText::prevSentence(int pos) const
 {
 	//we cannot go before the first position so just return it.
 	if (pos == 0)
@@ -2023,10 +2018,6 @@ void StoryText::select(int pos, int len, bool on)
 
 //	qDebug("old selection: %d - %d", d->selFirst, d->selLast);
 
-//	StoryText* that = const_cast<StoryText *>(this);
-//	for (int i = pos; i < pos + signed(len); ++i)
-//		that->at(i)->cselect = on;
-
 	if (on)
 	{
 		// extend if possible
@@ -2100,8 +2091,6 @@ void StoryText::fixSurrogateSelection()
 		d->selLast++;
 }
 
-BreakIterator* StoryText::m_graphemeIterator = nullptr;
-
 BreakIterator* StoryText::getGraphemeIterator()
 {
 	UErrorCode status = U_ZERO_ERROR;
@@ -2117,8 +2106,6 @@ BreakIterator* StoryText::getGraphemeIterator()
 	return m_graphemeIterator;
 }
 
-BreakIterator* StoryText::m_wordIterator = nullptr;
-
 BreakIterator* StoryText::getWordIterator()
 {
 	UErrorCode status = U_ZERO_ERROR;
@@ -2133,8 +2120,6 @@ BreakIterator* StoryText::getWordIterator()
 	return m_wordIterator;
 }
 
-BreakIterator* StoryText::m_sentenceIterator = nullptr;
-
 BreakIterator* StoryText::getSentenceIterator()
 {
 	UErrorCode status = U_ZERO_ERROR;
@@ -2150,8 +2135,6 @@ BreakIterator* StoryText::getSentenceIterator()
 	return m_sentenceIterator;
 }
 
-BreakIterator* StoryText::m_lineIterator = nullptr;
-
 BreakIterator* StoryText::getLineIterator()
 {
 	UErrorCode status = U_ZERO_ERROR;
@@ -2411,9 +2394,6 @@ void StoryText::saxx(SaxHandler& handler, const Xml_string& elemtag) const
 	handler.end("span");
 	handler.end("p");
 	
-//	if (!lastWasPar)
-//		paragraphStyle(length()-1).saxx(handler);
-	
 	handler.end(elemtag);
 }
 
@@ -2505,7 +2485,7 @@ public:
 		// We have to remove them from object list and add them to the FrameItems list
 		// before inserting them in story object
 		QList<PageItem*> *items = obj->doc()->Items;
-		if (items->count() > 0)
+		if (!items->isEmpty())
 		{
 			if (items->last() == obj) // try a fast path first
 				items->removeLast();
@@ -2672,75 +2652,10 @@ public:
 struct AppendMark : public MakeAction<AppendMark_body>
 {};
 
-/*
-class ApplyStyle_body : public Action_body
-{
-public:
-	void end(const Xml_string& tag) 
-	{
-		qDebug() << "storytext desaxe: apply style";
-		StoryText* story = this->dig->top<StoryText>(1);
-		ParagraphStyle* obj = this->dig->top<ParagraphStyle>(0);
-		story->applyStyle(-1, *obj);
-	}
-};
-
-struct ApplyStyle : public MakeAction<ApplyStyle_body>
-{};
-
-
-class ApplyCharStyle_body : public Action_body
-{
-public:
-	ApplyCharStyle_body() : storyTag(StoryText::saxxDefaultElem), lastPos(0), lastStyle()
-	{}
-	ApplyCharStyle_body(const Xml_string& tag) : storyTag(tag), lastPos(0), lastStyle()
-	{}
-	
-	void end(const Xml_string& tag) 
-	{
-		qDebug() << "storytext desaxe: apply charstyle";
-		if (tag == CharStyle::saxxDefaultElem)
-		{
-			StoryText* story = this->dig->top<StoryText>(1);
-			CharStyle* obj = this->dig->top<CharStyle>(0);
-			int len = story->length();
-			if (len > lastPos && lastStyle != *obj)
-			{
-				story->applyCharStyle(lastPos, len - lastPos, lastStyle);
-				lastPos = len;
-				lastStyle = *obj;
-			}
-		}
-		else if (tag == StoryText::saxxDefaultElem)
-		{
-			StoryText* story = this->dig->top<StoryText>();
-			int len = story->length();
-			if (len > lastPos)
-			{
-				story->applyCharStyle(lastPos, len - lastPos, lastStyle);
-			}
-		}
-	}
-private:
-	Xml_string storyTag;
-	int lastPos;
-	CharStyle lastStyle;
-};
-
-struct ApplyCharStyle : public MakeAction<ApplyCharStyle_body, const Xml_string&>
-{
-	ApplyCharStyle() : MakeAction<ApplyCharStyle_body, const Xml_string&>() {}
-	ApplyCharStyle(const Xml_string& tag) : MakeAction<ApplyCharStyle_body, const Xml_string&>(tag) {}
-};
-
-*/
-
 class Paragraph_body : public Action_body
 {
 public:
-	Paragraph_body()
-	{}
+	Paragraph_body() = default;
 	
 	~Paragraph_body() override
 	{
@@ -2800,15 +2715,14 @@ private:
 
 struct Paragraph : public MakeAction<Paragraph_body>
 {
-	Paragraph() {}
+	Paragraph() = default;
 };
 
 
 class SpanAction_body : public Action_body
 {
 public:
-	SpanAction_body()
-	{}
+	SpanAction_body() = default;
 	
 	~SpanAction_body() override
 	{
@@ -2852,7 +2766,7 @@ private:
 
 struct SpanAction : public MakeAction<SpanAction_body>
 {
-	SpanAction() {}
+	SpanAction() = default;
 };
 
 
