@@ -30,37 +30,37 @@ class SCRIBUS_API KCurve : public QWidget
 
 public:
 	KCurve(QWidget *parent);
-	virtual ~KCurve();
+	virtual ~KCurve() = default;
 
 protected:
-	void paintEvent(QPaintEvent *);
-	void keyPressEvent(QKeyEvent *);
-	void mousePressEvent (QMouseEvent * e);
-	void mouseReleaseEvent ( QMouseEvent * e );
-	void mouseMoveEvent ( QMouseEvent * e );
+	void paintEvent(QPaintEvent*) override;
+	void keyPressEvent(QKeyEvent*) override;
+	void mousePressEvent(QMouseEvent* e) override;
+	void mouseReleaseEvent(QMouseEvent* e) override;
+	void mouseMoveEvent(QMouseEvent* e) override;
 
 public:
-	double getCurveValue(double x);
-	FPointArray getCurve();
+	FPointArray getCurve() const;
 	void setCurve(const FPointArray& inlist);
 	void resetCurve();
+	QPainterPath curvePath() const;
 	void setLinear(bool setter);
-	bool isLinear();
+	bool isLinear() const;
 
 signals:
 	void modified();
 
 private:
-	double m_leftmost;
-	double m_rightmost;
-	FPoint m_grab_point;
-	int m_pos;
-	bool m_dragging;
-	bool m_linear;
-	double m_grabOffsetX;
-	double m_grabOffsetY;
+	int m_leftmost { 0 };
+	int m_rightmost { 0 };
+	bool m_dragging { false };
+	bool m_linear { false };
 	FPointArray m_points;
 	FPointArray m_points_back;
+	QPointF m_mousePos;
+	int m_selectedPoint { 0 };
+
+	int selectedPoint() const;
 };
 
 class SCRIBUS_API CurveWidget : public QWidget
@@ -72,12 +72,13 @@ public:
 	~CurveWidget() {};
 	
 	void setLinear(bool setter);
-	QPushButton* invertButton;
-	QPushButton* resetButton;
-	QPushButton *linearButton;
-	QPushButton* loadButton;
-	QPushButton* saveButton;
-	KCurve* cDisplay;
+
+	QPushButton* invertButton { nullptr };
+	QPushButton* resetButton { nullptr };
+	QPushButton *linearButton { nullptr };
+	QPushButton* loadButton { nullptr };
+	QPushButton* saveButton { nullptr };
+	KCurve* cDisplay { nullptr };
 
 private slots:
 	void doInvert();
@@ -87,9 +88,9 @@ private slots:
 	void doSave();
 
 protected:
-	QHBoxLayout* CurveWidgetLayout;
-	QVBoxLayout* layout1;
-	QSpacerItem* spacer1;
+	QHBoxLayout* CurveWidgetLayout { nullptr };
+	QVBoxLayout* layout1 { nullptr };
+	QSpacerItem* spacer1 { nullptr };
 
 	void changeEvent(QEvent *e) override;
 
