@@ -26,6 +26,7 @@ for which a new license (GPL+exception) is in place.
 
 #include <QList>
 #include <QFrame>
+#include <QEnterEvent>
 #include <QPaintEvent>
 #include <QMouseEvent>
 #include <QKeyEvent>
@@ -33,11 +34,13 @@ for which a new license (GPL+exception) is in place.
 #include <QHBoxLayout>
 
 class QEvent;
+class ScColor;
 
 #include "scribusapi.h"
 #include "vgradient.h"
 
-class SCRIBUS_API GradientPreview : public QFrame
+
+/*class SCRIBUS_API GradientPreview : public QFrame
 {
 	Q_OBJECT
 
@@ -65,12 +68,12 @@ public:
 
 protected:
 	void paintEvent(QPaintEvent* e) override;
-	void keyPressEvent(QKeyEvent*)  override;
-	void mousePressEvent(QMouseEvent* m)  override;
-	void mouseReleaseEvent(QMouseEvent*)  override;
-	void mouseMoveEvent(QMouseEvent* m)  override;
-	void leaveEvent(QEvent*)  override;
-	void enterEvent(QEvent*)  override;
+	void keyPressEvent(QKeyEvent*) override;
+	void mousePressEvent(QMouseEvent* m) override;
+	void mouseReleaseEvent(QMouseEvent*) override;
+	void mouseMoveEvent(QMouseEvent* m) override;
+	void leaveEvent(QEvent*) override;
+	void enterEvent(QEnterEvent*) override;
 
 private:
 	VGradient fill_gradient;
@@ -86,4 +89,66 @@ signals:
 	void currStep(double);
 	void gradientChanged();
 };
+*/
+
+class SCRIBUS_API GradientPreview : public QWidget
+{
+	Q_OBJECT
+public:
+	explicit GradientPreview(QWidget *parent = nullptr);
+	~GradientPreview() {};
+
+	void setActiveStopColor(const QColor& c, const QString& n, int s, double a);
+	QColor activeStopColor() const;
+
+	void setActiveStopPosition(double t);
+
+	void setIsEditable(bool isEditable);
+	bool isEditable() const;
+
+	void setGradient(const VGradient& gradient);
+	const VGradient& gradient() const;
+
+	void updateDisplay();
+
+protected:
+	void paintEvent(QPaintEvent* e);
+	void keyPressEvent(QKeyEvent* e);
+	void mousePressEvent(QMouseEvent* m);
+	void mouseReleaseEvent(QMouseEvent* m);
+	void mouseMoveEvent(QMouseEvent* m);
+
+private:
+	VGradient fill_gradient;
+	QPointF m_mousePos;
+	bool m_isEditable { true };
+	int m_activeStop { 0 };
+	int m_tmpStop { 0 };
+
+	QRect saveAreaRect() const;
+	QRect canvasRect() const;
+	QRect scaleRect() const;
+	QRect handleRect(int center) const;
+	QRect stopRect(int center) const;
+	qreal ratio() const;
+	bool isMouseOutside(QPoint mouse) const;
+	int mapPositionToGrid(qreal pos) const;
+	int stopAtPosition(QPoint position) const;
+	VColorStop *activeStop(int offset = 0) const;
+	double percentFromPosition(QPointF position) const;
+	int percentToPosition(double t) const;
+
+	void setup();
+	void addStop(QPoint mousePosition);
+	void removeStop();
+	void emitStopPosition();
+	void emitStop();
+	void updateTmpStop(double t);
+	void sortStops();
+
+signals:
+	void selectedStop(VColorStop*);
+	void selectedPosition(double);
+
+};
 #endif
