@@ -10,14 +10,15 @@ class SCRIBUS_API MarkVariableText : public MarkInsert, private Ui::MarkVariable
 	Q_OBJECT
 
 public:
-	explicit MarkVariableText(const QList<Mark*>&, QWidget *parent = 0);
-	explicit MarkVariableText(const Mark*, QWidget *parent = 0);
+	explicit MarkVariableText(const QList<Mark*>&, QWidget* parent = nullptr);
+	explicit MarkVariableText(const Mark*, QWidget* parent = nullptr);
 	~MarkVariableText();
-	virtual Mark* values(QString& label, QString& text);
-	virtual void setValues(const QString label, const QString text);
+
+	Mark* values(QString& label, QString& text) override;
+	void setValues(const QString label, const QString text) override;
 
 protected:
-	void changeEvent(QEvent *e);
+	void changeEvent(QEvent *e) override;
 
 private slots:
 	void onLabelList_currentIndexChanged(int index);
@@ -30,10 +31,10 @@ private:
 		LineEdit = 1
 	};
 
-	QWidget* labelEditWidget;
+	QWidget* labelEditWidget = nullptr;
 	const WidgetType m_widgetType;
 
-	const Mark* m_mark;
+	const Mark* m_mark = nullptr;
 };
 
 #endif // MARKVARIABLETEXT_H
