@@ -7,6 +7,7 @@ for which a new license (GPL+exception) is in place.
 #ifndef MULTIPLEDUPLICATE
 #define MULTIPLEDUPLICATE
 
+#include <QDialog>
 #include "ui_multipleduplicate.h"
 struct ItemMultipleDuplicateData;
 class ScribusDoc;
@@ -20,7 +21,7 @@ class MultipleDuplicate : public QDialog, Ui::MultipleDuplicate
 		void getMultiplyData(ItemMultipleDuplicateData&);
 	protected:
 		// int m_unitIndex;
-		ScribusDoc *m_Doc;
+		ScribusDoc *m_Doc { nullptr };
 		double m_unitRatio;
 	protected slots:
 		void setCopiesShift();
