@@ -6,6 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 
 #include <QEvent>
+#include <QListView>
 
 #include "iconmanager.h"
 #include "langmgr.h"
@@ -22,27 +23,27 @@ SMCStyleWidget::SMCStyleWidget(QWidget *parent)
 {
 	setupUi(this);
 
-	iconSetChange();
+	textColor->colorButton->setContext(Context::Text);
+	textColor->setColor(CommonStrings::tr_NoneColor);
+	textColor->setText(tr("Color"));
 
-	fillColor_->setPixmapType(ColorCombo::fancyPixmaps);
-	fillColor_->clear();
-	fillColor_->addItem(CommonStrings::tr_NoneColor);
+	backgroundColor->colorButton->setContext(Context::TextBackground);
+	backgroundColor->setColor(CommonStrings::tr_NoneColor);
+	backgroundColor->setText(tr("Background"));
 
-	strokeColor_->setPixmapType(ColorCombo::fancyPixmaps);
-	strokeColor_->clear();
-	strokeColor_->addItem(CommonStrings::tr_NoneColor);
+	strokeColor->colorButton->setContext(Context::TextOutline);
+	strokeColor->setColor(CommonStrings::tr_NoneColor);
+	strokeColor->setText(tr("Stroke"));
+	strokeColor->setEnabled(false);
 
-	backColor_->setPixmapType(ColorCombo::fancyPixmaps);
-	backColor_->clear();
-	backColor_->addItem(CommonStrings::tr_NoneColor);
-
-	StrokeIcon->setEnabled(false);
-	strokeShade_->setEnabled(false);
-	strokeColor_->setEnabled(false);
 	fontfeaturesSetting->resetFontFeatures();
 
 	hyphenCharLineEdit->setMaxLength(1);
 
+	fontFace_->setGuestWidget(fontSizeLabel_);
+
+	iconSetChange();
+
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 
 	connect(effects_, SIGNAL(State(int)), this, SLOT(slotColorChange()));
@@ -63,18 +64,18 @@ void SMCStyleWidget::iconSetChange()
 {
 	IconManager& im = IconManager::instance();
 
-	fontSizeLabel_->setPixmap(im.loadPixmap("zeichen.png"));
-	trackingLabel_->setPixmap(im.loadPixmap("textkern.png"));
-	widthSpaceLabel->setPixmap(im.loadPixmap("spacewidth.png"));
-	baselineOffsetLabel_->setPixmap(im.loadPixmap("textbase.png"));
-	hscaleLabel_->setPixmap(im.loadPixmap("textscaleh.png"));
-	vscaleLabel_->setPixmap(im.loadPixmap("textscalev.png"));
-	FillIcon->setPixmap(im.loadPixmap("16/color-fill.png"));
-	fillShadeLabel->setPixmap(im.loadPixmap("shade.png"));
-	StrokeIcon->setPixmap(im.loadPixmap("16/color-stroke.png"));
-	strokeShadeLabel->setPixmap(im.loadPixmap("shade.png"));
-	backIcon->setPixmap(im.loadPixmap("16/color-fill.png"));
-	backShadeLabel->setPixmap(im.loadPixmap("shade.png"));
+	fontSizeLabel_->setPixmap(im.loadPixmap("font-size"));
+	trackingLabel_->setPixmap(im.loadPixmap("character-letter-tracking"));
+	widthSpaceLabel->setPixmap(im.loadPixmap("character-space-width"));
+	baselineOffsetLabel_->setPixmap(im.loadPixmap("character-offset-baseline"));
+	hscaleLabel_->setPixmap(im.loadPixmap("character-scale-width"));
+	vscaleLabel_->setPixmap(im.loadPixmap("character-scale-height"));
+	languageLabel_->setPixmap(im.loadPixmap("paragraph-language"));
+	hyphenationCharacterLabel->setPixmap(im.loadPixmap("hyphen-character"));
+	smallestWordLabel->setPixmap(im.loadPixmap("hyphen-smallest-word"));
+	textColor->setPixmap(im.loadPixmap("text-color"));
+	strokeColor->setPixmap(im.loadPixmap("text-outline-color"));
+	backgroundColor->setPixmap(im.loadPixmap("text-background-color"));
 }
 
 void SMCStyleWidget::languageChange()
@@ -83,27 +84,6 @@ void SMCStyleWidget::languageChange()
 	LanguageManager::instance()->fillInstalledStringList(&languageList);
 	fillLangComboFromList(languageList);
 
-	if (fillColor_->count() > 0)
-	{
-		bool sigBlocked = fillColor_->blockSignals(true);
-		fillColor_->setItemText(0, CommonStrings::tr_NoneColor);
-		fillColor_->blockSignals(sigBlocked);
-	}
-
-	if (strokeColor_->count() > 0)
-	{
-		bool sigBlocked = strokeColor_->blockSignals(true);
-		strokeColor_->setItemText(0, CommonStrings::tr_NoneColor);
-		strokeColor_->blockSignals(sigBlocked);
-	}
-
-	if (backColor_->count() > 0)
-	{
-		bool sigBlocked = backColor_->blockSignals(true);
-		backColor_->setItemText(0, CommonStrings::tr_NoneColor);
-		backColor_->blockSignals(sigBlocked);
-	}
-
 	retranslateUi(this);
 
 	fontSizeLabel_->setToolTip(fontSize_->toolTip());
@@ -112,12 +92,15 @@ void SMCStyleWidget::languageChange()
 	baselineOffsetLabel_->setToolTip(baselineOffset_->toolTip());
 	hscaleLabel_->setToolTip(fontHScale_->toolTip());
 	vscaleLabel_->setToolTip(fontVScale_->toolTip());
-	FillIcon->setToolTip(fillColor_->toolTip());
-	fillShadeLabel->setToolTip(fillShade_->toolTip());
-	StrokeIcon->setToolTip(strokeColor_->toolTip());
-	strokeShadeLabel->setToolTip(strokeShade_->toolTip());
-	backIcon->setToolTip(backColor_->toolTip());
-	backShadeLabel->setToolTip(backShade_->toolTip());
+
+	textColor->colorButton->setPersistentToolTip( tr("Text color of selected text"));
+	textColor->setText(tr("Color"));
+
+	backgroundColor->colorButton->setPersistentToolTip( tr("Background color of selected text"));
+	backgroundColor->setText(tr("Background"));
+
+	strokeColor->colorButton->setPersistentToolTip( tr("Stroke color of selected text"));
+	strokeColor->setText(tr("Stroke"));
 
 // 	fontVScale_->setSuffix( tr(" %"));
 // 	fontHScale_->setSuffix( tr(" %"));
@@ -158,23 +141,11 @@ void SMCStyleWidget::fillLangComboFromList(const QStringList& langList)
 		tmpView->setMinimumWidth(tmpWidth + 24);
 }
 
-void SMCStyleWidget::fillColorCombo(ColorList &colors)
-{
-	fillColor_->clear();
-	strokeColor_->clear();
-	backColor_->clear();
-
-	fillColor_->setColors(colors, true);
-	strokeColor_->setColors(colors, true);
-	backColor_->setColors(colors, true);
-}
-
 void SMCStyleWidget::handleUpdateRequest(int updateFlags)
 {
 	if (!m_Doc)
 		return;
-	if (updateFlags & reqColorsUpdate)
-		fillColorCombo(m_Doc->PageColors);
+
 }
 
 void SMCStyleWidget::slotEnableFontFeatures(const QString& s)
@@ -195,9 +166,12 @@ void SMCStyleWidget::setDoc(ScribusDoc *doc)
 	QStringList languageList;
 	LanguageManager::instance()->fillInstalledStringList(&languageList);
 	fillLangComboFromList(languageList);
-	fillColorCombo(m_Doc->PageColors);
 	fontFace_->rebuildList(m_Doc);
 
+	textColor->colorButton->setDoc(m_Doc);
+	backgroundColor->colorButton->setDoc(m_Doc);
+	strokeColor->colorButton->setDoc(m_Doc);
+
 	connect(m_Doc->scMW(), SIGNAL(UpdateRequest(int)), this , SLOT(handleUpdateRequest(int)));
 }
 
@@ -230,23 +204,9 @@ void SMCStyleWidget::show(const CharStyle *cstyle, const QList<CharStyle> &cstyl
 		effects_->setStyle(static_cast<int>(cstyle->effects()), cstyle->isInhFeatures());
 		effects_->setParentItem(static_cast<int>(parent->effects())); // FIXME
 
-		fillShade_->setValue(qRound(cstyle->fillShade()), cstyle->isInhFillShade());
-		fillShade_->setParentValue(qRound(parent->fillShade()));
-
-		strokeShade_->setValue(qRound(cstyle->strokeShade()), cstyle->isInhStrokeShade());
-		strokeShade_->setParentValue(qRound(parent->strokeShade()));
-
-		fillColor_->setCurrentText(cstyle->fillColor(), cstyle->isInhFillColor());
-		fillColor_->setParentText(parent->fillColor());
-
-		strokeColor_->setCurrentText(cstyle->strokeColor(), cstyle->isInhStrokeColor());
-		strokeColor_->setParentText(parent->strokeColor());
-
-		backColor_->setCurrentText(cstyle->backColor(), cstyle->isInhBackColor());
-		backColor_->setParentText(parent->backColor());
-
-		backShade_->setValue(qRound(cstyle->backShade()), cstyle->isInhBackShade());
-		backShade_->setParentValue(qRound(parent->backShade()));
+		textColor->setColor(cstyle->fillColor(), qRound(cstyle->fillShade()), parent->fillColor(), qRound(cstyle->fillShade()), cstyle->isInhFillColor());
+		backgroundColor->setColor(cstyle->backColor(), qRound(cstyle->backShade()), parent->backColor(), qRound(cstyle->backShade()), cstyle->isInhBackColor());
+		strokeColor->setColor(cstyle->strokeColor(), qRound(cstyle->strokeShade()), parent->strokeColor(), qRound(cstyle->strokeShade()), cstyle->isInhStrokeColor());
 
 		fontFace_->setCurrentFont(cstyle->font().scName(), cstyle->isInhFont());
 		fontFace_->setParentFont(parent->font().scName());
@@ -257,13 +217,13 @@ void SMCStyleWidget::show(const CharStyle *cstyle, const QList<CharStyle> &cstyl
 		smallestWordSpinBox->setValue(cstyle->hyphenWordMin(), cstyle->isInhHyphenWordMin());
 		smallestWordSpinBox->setParentValue(parent->hyphenWordMin());
 
-		uint hyphenChar = cstyle->hyphenChar();
+		char32_t hyphenChar = cstyle->hyphenChar();
 		QString hyphenText;
 		if (hyphenChar)
 			hyphenText = QString::fromUcs4(&hyphenChar, 1);
 		hyphenCharLineEdit->setValue(hyphenText, cstyle->isInhHyphenChar());
 
-		uint parentHyphenChar = parent->hyphenChar();
+		char32_t parentHyphenChar = parent->hyphenChar();
 		QString parentHyphenText;
 		if (parentHyphenChar)
 			parentHyphenText = QString::fromUcs4(&parentHyphenChar, 1);
@@ -278,17 +238,16 @@ void SMCStyleWidget::show(const CharStyle *cstyle, const QList<CharStyle> &cstyl
 		tracking_->setValue(cstyle->tracking() / 10.0);
 		widthSpaceSpin->setValue(cstyle->wordTracking() * 100.0);
 		effects_->setStyle(static_cast<int>(cstyle->effects()));
-		fillShade_->setValue(qRound(cstyle->fillShade()));
-		strokeShade_->setValue(qRound(cstyle->strokeShade()));
-		fillColor_->setCurrentText(cstyle->fillColor());
-		strokeColor_->setCurrentText(cstyle->strokeColor());
-		backColor_->setCurrentText(cstyle->backColor());
-		backShade_->setValue(qRound(cstyle->backShade()));
+
+		textColor->setColor(cstyle->fillColor(), qRound(cstyle->fillShade()));
+		backgroundColor->setColor(cstyle->backColor(), qRound(cstyle->backShade()));
+		strokeColor->setColor(cstyle->strokeColor(), qRound(cstyle->strokeShade()));
+
 		fontFace_->setCurrentFont(cstyle->font().scName());
 		fontfeaturesSetting->setFontFeatures(cstyle->fontFeatures(), cstyle->font().fontFeatures());
 		smallestWordSpinBox->setValue(cstyle->hyphenWordMin());
 
-		uint hyphenChar = cstyle->hyphenChar();
+		char32_t hyphenChar = cstyle->hyphenChar();
 		QString hyphenText;
 		if (hyphenChar)
 			hyphenText = QString::fromUcs4(&hyphenChar, 1);
@@ -509,8 +468,7 @@ void SMCStyleWidget::showEffects(const QList<CharStyle*> &cstyles)
 
 void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 {
-	strokeShade_->setEnabled(true);
-	strokeColor_->setEnabled(true);
+	strokeColor->setEnabled(true);
 
 	double d = -30000;
 	for (int i = 0; i < cstyles.count(); ++i)
@@ -522,46 +480,6 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 		}
 		d = cstyles[i]->fillShade();
 	}
-	if (d == -30000)
-		fillShade_->setText( tr("Shade"));
-	else
-		fillShade_->setValue(qRound(d));
-
-	d = -30000;
-	for (int i = 0; i < cstyles.count(); ++i)
-	{
-		if (d != -30000 && cstyles[i]->strokeShade() != d)
-		{
-			d = -30000;
-			break;
-		}
-		d = cstyles[i]->strokeShade();
-	}
-	if (d == -30000)
-	{
-		strokeShade_->setValue(21);
-		strokeShade_->setText( tr("Shade"));
-	}
-	else
-		strokeShade_->setValue(qRound(d));
-
-	d = -30000;
-	for (int i = 0; i < cstyles.count(); ++i)
-	{
-		if (d != -30000 && cstyles[i]->backShade() != d)
-		{
-			d = -30000;
-			break;
-		}
-		d = cstyles[i]->backShade();
-	}
-	if (d == -30000)
-	{
-		backShade_->setValue(21);
-		backShade_->setText( tr("Shade"));
-	}
-	else
-		backShade_->setValue(qRound(d));
 
 	QString s;
 	for (int i = 0; i < cstyles.count(); ++i)
@@ -573,14 +491,20 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 		}
 		s = cstyles[i]->fillColor();
 	}
-	if (s.isEmpty())
+
+	textColor->setColor(s, qRound(d));
+
+	// Stroke
+	d = -30000;
+	for (int i = 0; i < cstyles.count(); ++i)
 	{
-		if (fillColor_->itemText(fillColor_->count() - 1) != "")
-			fillColor_->addItem("");
-		fillColor_->setCurrentIndex(fillColor_->count() - 1);
+		if (d != -30000 && cstyles[i]->strokeShade() != d)
+		{
+			d = -30000;
+			break;
+		}
+		d = cstyles[i]->strokeShade();
 	}
-	else
-		fillColor_->setCurrentText(s);
 
 	s.clear();
 	for (int i = 0; i < cstyles.count(); ++i)
@@ -592,14 +516,20 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 		}
 		s = cstyles[i]->strokeColor();
 	}
-	if (s.isEmpty())
+
+	strokeColor->setColor(s, qRound(d));
+
+	// Background
+	d = -30000;
+	for (int i = 0; i < cstyles.count(); ++i)
 	{
-		if (strokeColor_->itemText(strokeColor_->count() - 1) != "")
-			strokeColor_->addItem("");
-		strokeColor_->setCurrentIndex(strokeColor_->count() - 1);
+		if (d != -30000 && cstyles[i]->backShade() != d)
+		{
+			d = -30000;
+			break;
+		}
+		d = cstyles[i]->backShade();
 	}
-	else
-		strokeColor_->setCurrentText(s);
 
 	s.clear();
 	for (int i = 0; i < cstyles.count(); ++i)
@@ -611,14 +541,9 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 		}
 		s = cstyles[i]->backColor();
 	}
-	if (s.isEmpty())
-	{
-		if (backColor_->itemText(backColor_->count() - 1) != "")
-			backColor_->addItem("");
-		backColor_->setCurrentIndex(backColor_->count() - 1);
-	}
-	else
-		backColor_->setCurrentText(s);
+
+	backgroundColor->setColor(s, qRound(d));
+
 }
 
 void SMCStyleWidget::showLanguage(const QList<CharStyle*> &cstyles, const QString& /*defLang*/)
@@ -661,8 +586,8 @@ void SMCStyleWidget::showSmallestWord(const QList<CharStyle *> &cstyles)
 
 void SMCStyleWidget::showHyphenChar(const QList<CharStyle *> &cstyles)
 {
-	uint empty = 0;
-	uint ch(cstyles[0]->hyphenChar());
+	char32_t empty = 0;
+	char32_t ch(cstyles[0]->hyphenChar());
 	for (int i = 0; i < cstyles.count(); ++i)
 	{
 		if (ch != cstyles[i]->hyphenChar())
@@ -713,7 +638,6 @@ void SMCStyleWidget::slotColorChange()
 {
 	int s = effects_->getStyle();
 	bool enabled= (s & 4) || (s & 256);
-	StrokeIcon->setEnabled(enabled);
-	strokeShade_->setEnabled(enabled);
-	strokeColor_->setEnabled(enabled);
+
+	strokeColor->setEnabled(enabled);
 }
