@@ -152,7 +152,7 @@ public:
 	UndoTransaction beginTransaction(const TransactionSettings& settings);
 	
 	/**
-	 * @brief Cancels the current transaction and deletes groupped <code>UndoState</code>s.
+	 * @brief Cancels the current transaction and deletes grouped <code>UndoState</code>s.
 	 * @brief Nothing from canceled transaction will be sent to the undo gui widgets.
 	 */
 	//void cancelTransaction();
@@ -396,6 +396,7 @@ public:
 	static int     ItemsInvolvedLimit;
 	static QString Cancel;
 	static QString SetFill;
+	static QString SetFillRule;
 	static QString ColorFromTo;
 	static QString SetShade;
 	static QString SetLineColor;
