@@ -47,7 +47,7 @@ for which a new license (GPL+exception) is in place.
 #include <cxxabi.h>
 #endif
 #if defined(_WIN32)
-#include <windows.h>
+#include <Windows.h>
 #endif
 
 using namespace std;
@@ -1033,6 +1033,20 @@ bool convertOldTable(ScribusDoc *m_Doc, PageItem* gItem, QList<PageItem*> &gpL,
 	QList<double> colWidths;
 	QList<double> rowHeights;
 
+	// Check the provided group is indeed in the PageItem list provided
+	if (target != nullptr)
+	{
+		int ind = target->indexOf(gItem);
+		if (ind < 0)
+			return false;
+	}
+	else
+	{
+		int ind = m_Doc->FrameItems.key(gItem, -1);
+		if (ind < 0)
+			return false;
+	}
+
 	// 1. Although this was not intended, legacy tables allowed user to link frames together
 	// New table do not support that, so if one frame has any link, we stop the conversion
 	// here, those frame will be converted to a standard group.
