@@ -195,7 +195,7 @@ static quint64 code64(const ScColor & col)
 	if (col.getColorModel() == colorModelRGB)
 	{
 		col.getRGB(&R, &G, &B);
-		QColor color = QColor(R, G, B);
+		QColor color(R, G, B);
 		color.getCmyk(&C, &M, &Y, &K);
 	}
 	else if (col.getColorModel() == colorModelCMYK)
@@ -213,7 +213,7 @@ static quint64 code64(const ScColor & col)
 		G = qRound(a + 128);
 		B = qRound(b + 128);
 	}
-	result |= col.getColorModel() == colorModelRGB ? 1 : 0;
+	result |= static_cast<unsigned char>(col.getColorModel());
 	result |= col.isSpotColor() ? 64 : 0;
 	result |= col.isRegistrationColor() ? 32 : 0;
 	result <<= 8;
@@ -248,12 +248,12 @@ QPixmap * getFancyPixmap(const ScColor& col, ScribusDoc* doc)
 	if (!iconsInitialized)
 	{
 		IconManager& im = IconManager::instance();
-		alertIcon = im.loadPixmap("alert.png");
-		cmykIcon = im.loadPixmap("cmyk.png");
-		rgbIcon = im.loadPixmap("rgb.png");
-		labIcon = im.loadPixmap("lab.png");
-		spotIcon = im.loadPixmap("spot.png");
-		regIcon = im.loadPixmap("register.png");
+		alertIcon = im.loadPixmap("alert-warning");
+		cmykIcon = im.loadPixmap("color-cmyk");
+		rgbIcon = im.loadPixmap("color-rgb");
+		labIcon = im.loadPixmap("color-lab");
+		spotIcon = im.loadPixmap("color-spot");
+		regIcon = im.loadPixmap("color-registration");
 		iconsInitialized = true;
 	}
 
